(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    185029,       3637]
NotebookOptionsPosition[    182226,       3545]
NotebookOutlinePosition[    182570,       3560]
CellTagsIndexPosition[    182527,       3557]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "H\[ADoubleDot]ufigkeitsverteilung von SNPs"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.6703223159323993`*^9, 
  3.6703240630715284`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "In diesem ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs werden wir (lokal gespeicherte) Daten aus dem ",
 StyleBox["UCSC Genome Browser ",
  FontSlant->"Italic"],
 "in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " verarbeiten. \[CapitalUDoubleDot]ber die Exportfunktion des ",
 StyleBox["Genome Browser",
  FontSlant->"Italic"],
 " haben wir den GWAS Catalog in eine Datei ",
 StyleBox["gwas_temp",
  FontWeight->"Bold"],
 " geschrieben, die wir zuerst einlesen."
}], "Text",
 CellChangeTimes->{{3.6746231248173265`*^9, 3.674623139257348*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.6775525917540574`*^9, 3.677552629334523*^9}, 
   3.6775526709875965`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"gwas1", " ", "=", " ", 
   RowBox[{"Import", "[", "\"\<gwas_temp\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613962037714135*^9, 3.6139620587800694`*^9}, {
  3.671610368693144*^9, 3.6716103719763317`*^9}, {3.671610454451049*^9, 
  3.671610455080085*^9}}],

Cell[TextData[{
 "Die Daten enthalten alle Einzelnukleotidpolymorphismen (SNPs), die in \
publizierten GWAS-Daten mit ausreichender H\[ADoubleDot]ufigkeit \
identifiziert worden sind und im ",
 StyleBox["Catalog of Published Genome-Wide Association Studies",
  FontSlant->"Italic"],
 " am ",
 StyleBox["National Human Genome Research Institute",
  FontSlant->"Italic"],
 " (NHGRI) abgelegt sind. Es handelt sich um etwa 19 000 Eintr\[ADoubleDot]ge:"
}], "Text",
 CellChangeTimes->{{3.674623210339453*^9, 3.6746232448275037`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "gwas1", "]"}]], "Input",
 CellChangeTimes->{{3.6138078881437674`*^9, 3.613807893501628*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19880", ",", "23"}], "}"}]], "Output",
 CellChangeTimes->{3.6775709881738634`*^9}]
}, Open  ]],

Cell["\<\
Die erste Zeile dieser Liste enth\[ADoubleDot]lt die Spaltenbeschriftung:\
\>", "Text",
 CellChangeTimes->{{3.6746232587045245`*^9, 3.6746232810355573`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gwas1", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.613807903059449*^9, 3.613807906386208*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"#bin\"\>", ",", "\<\"chrom\"\>", ",", "\<\"chromStart\"\>", 
   ",", "\<\"chromEnd\"\>", ",", "\<\"name\"\>", ",", "\<\"pubMedID\"\>", 
   ",", "\<\"author\"\>", ",", "\<\"pubDate\"\>", ",", "\<\"journal\"\>", 
   ",", "\<\"title\"\>", ",", "\<\"trait\"\>", ",", "\<\"initSample\"\>", 
   ",", "\<\"replSample\"\>", ",", "\<\"region\"\>", ",", "\<\"genes\"\>", 
   ",", "\<\"riskAllele\"\>", ",", "\<\"riskAlFreq\"\>", 
   ",", "\<\"pValue\"\>", ",", "\<\"pValueDesc\"\>", ",", "\<\"orOrBeta\"\>", 
   ",", "\<\"ci95\"\>", ",", "\<\"platform\"\>", ",", "\<\"cnv\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6775709881894636`*^9}]
}, Open  ]],

Cell[TextData[{
 "F\[UDoubleDot]r unsere Analyse sind wir vor allem an den Spalten 2 (dem \
Chromosom), 3 (dem Startpunkt des SNP) und 17 (der prozentualen \
H\[ADoubleDot]ufigkeit dieses SNP in der Population) interessiert. Wir \
beginnen mit der Frage, wie die H\[ADoubleDot]ufigkeiten verteilt sind und \
wie sich die SNPs \[UDoubleDot]ber die Chromosomen verteilen. In einer Liste ",
 StyleBox["gwas2",
  FontWeight->"Bold"],
 " fassen wir die Spalten 2 und 17 zusammen (und beschr\[ADoubleDot]nken uns \
auf die F\[ADoubleDot]lle, bei denen eine reelle Zahl als \
H\[ADoubleDot]ufigkeit eingetragen ist):"
}], "Text",
 CellChangeTimes->{{3.674623306588594*^9, 3.6746233310866294`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gwas2", " ", "=", " ", 
   RowBox[{"Cases", "[", 
    RowBox[{
     RowBox[{"gwas1", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "17"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_Real"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6138079526529417`*^9, 3.613807983090645*^9}, {
  3.6138081747327433`*^9, 3.6138081830460463`*^9}, {3.613808284289649*^9, 
  3.613808293728606*^9}}],

Cell[TextData[{
 "Der Befehl ",
 StyleBox["Histogram",
  FontWeight->"Bold"],
 " f\[UDoubleDot]hrt sofort auf die Verteilung der SNP-Prozentzahlen."
}], "Text",
 CellChangeTimes->{{3.674623381498703*^9, 3.674623391368717*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"gwas2", " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", "n2"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", "Automatic"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.613808300823367*^9, 3.6138083174177837`*^9}, {
   3.613962606590464*^9, 3.613962686442957*^9}, 3.622882715496231*^9}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5459999999999999], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5459999999999999], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0}, {0.05, 869}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{33.0969387755102, 
          48.8295918367347}, {-39.0379438974758, 86.88119438899717}}],
        StatusArea[#, 869]& ,
        TagBoxNote->"869"],
       StyleBox["869", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[869, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.05, 0}, {0.1, 969}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{48.3295918367347, 
          64.06224489795919}, {-53.47052597877304, 86.88119438899717}}],
        StatusArea[#, 969]& ,
        TagBoxNote->"969"],
       StyleBox["969", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[969, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.1, 0}, {0.15, 1291}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{63.56224489795919, 
          79.29489795918369}, {-99.94344028055012, 86.88119438899717}}],
        StatusArea[#, 1291]& ,
        TagBoxNote->"1291"],
       StyleBox["1291", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1291, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.15, 0}, {0.2, 1074}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{78.79489795918369, 
          94.52755102040818}, {-68.62473716413514, 86.88119438899717}}],
        StatusArea[#, 1074]& ,
        TagBoxNote->"1074"],
       StyleBox["1074", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1074, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.2, 0}, {0.25, 1084}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{94.02755102040818, 
          109.76020408163268`}, {-70.06799537226486, 86.88119438899717}}],
        StatusArea[#, 1084]& ,
        TagBoxNote->"1084"],
       StyleBox["1084", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1084, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.25, 0}, {0.3, 1023}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{109.26020408163268`, 
          124.99285714285716`}, {-61.26412030267353, 86.88119438899717}}],
        StatusArea[#, 1023]& ,
        TagBoxNote->"1023"],
       StyleBox["1023", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1023, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.3, 0}, {0.35, 948}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{124.49285714285716`, 
          140.22551020408164`}, {-50.43968374170062, 86.88119438899717}}],
        StatusArea[#, 948]& ,
        TagBoxNote->"948"],
       StyleBox["948", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[948, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.35, 0}, {0.4, 1006}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{139.72551020408164`, 
          155.45816326530615`}, {-58.810581348853006`, 86.88119438899717}}],
        StatusArea[#, 1006]& ,
        TagBoxNote->"1006"],
       StyleBox["1006", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1006, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.4, 0}, {0.45, 955}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{154.95816326530615`, 
          170.69081632653067`}, {-51.449964487391426`, 86.88119438899717}}],
        StatusArea[#, 955]& ,
        TagBoxNote->"955"],
       StyleBox["955", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[955, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.45, 0}, {0.5, 918}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{170.19081632653067`, 
          185.92346938775515`}, {-46.10990911731143, 86.88119438899717}}],
        StatusArea[#, 918]& ,
        TagBoxNote->"918"],
       StyleBox["918", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[918, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.5, 0}, {0.55, 512}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{185.42346938775515`, 201.15612244897966`}, {
          12.48637413275533, 86.88119438899717}}],
        StatusArea[#, 512]& ,
        TagBoxNote->"512"],
       StyleBox["512", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[512, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.55, 0}, {0.6, 472}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{200.65612244897966`, 216.38877551020414`}, {
          18.259406965274223`, 86.88119438899717}}],
        StatusArea[#, 472]& ,
        TagBoxNote->"472"],
       StyleBox["472", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[472, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.6, 0}, {0.65, 516}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{215.88877551020414`, 231.62142857142862`}, {
          11.909070849503436`, 86.88119438899717}}],
        StatusArea[#, 516]& ,
        TagBoxNote->"516"],
       StyleBox["516", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[516, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.65, 0}, {0.7, 415}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{231.12142857142862`, 246.8540816326531}, {
          26.48597875161365, 86.88119438899717}}],
        StatusArea[#, 415]& ,
        TagBoxNote->"415"],
       StyleBox["415", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[415, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.7, 0}, {0.75, 409}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{246.3540816326531, 262.0867346938776}, {
          27.351933676491484`, 86.88119438899717}}],
        StatusArea[#, 409]& ,
        TagBoxNote->"409"],
       StyleBox["409", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[409, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.75, 0}, {0.8, 413}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{261.5867346938776, 277.3193877551021}, {
          26.77463039323959, 86.88119438899717}}],
        StatusArea[#, 413]& ,
        TagBoxNote->"413"],
       StyleBox["413", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[413, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.8, 0}, {0.85, 461}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{276.8193877551021, 292.55204081632655`}, {
          19.846990994216924`, 86.88119438899717}}],
        StatusArea[#, 461]& ,
        TagBoxNote->"461"],
       StyleBox["461", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[461, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.85, 0}, {0.9, 395}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{292.05204081632655`, 307.7846938775511}, {
          29.372495167873097`, 86.88119438899717}}],
        StatusArea[#, 395]& ,
        TagBoxNote->"395"],
       StyleBox["395", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[395, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.9, 0}, {0.95, 348}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{307.2846938775511, 323.0173469387756}, {
          36.1558087460828, 86.88119438899717}}],
        StatusArea[#, 348]& ,
        TagBoxNote->"348"],
       StyleBox["348", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[348, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.95, 0}, {1., 227}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{322.5173469387756, 338.25000000000006`}, {
          53.61923306445245, 86.88119438899717}}],
        StatusArea[#, 227]& ,
        TagBoxNote->"227"],
       StyleBox["227", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[227, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{1.2, 0}, {1.25, 1}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{398.68061224489804`, 414.4132653061225}, {
          86.2368685681842, 86.88119438899717}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.02, 0},
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0, 1}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677570989109865*^9}]
}, Open  ]],

Cell[TextData[{
 "Der Output dieses Befehls ist in Abb. 2.26 dargestellt.\n\nMit dem Befehl ",
 StyleBox["Tally",
  FontWeight->"Bold"],
 " l\[ADoubleDot]sst sich feststellen, wie h\[ADoubleDot]ufig jedes Chromosom \
genannt ist:"
}], "Text",
 CellChangeTimes->{{3.674623410709747*^9, 3.674623438264787*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"gwas2", " ", "/.", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", "n1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613808345542831*^9, 3.6138083513588333`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"chr1\"\>", ",", "1075"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr2\"\>", ",", "1044"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr3\"\>", ",", "696"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr4\"\>", ",", "561"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr5\"\>", ",", "651"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6\"\>", ",", "1182"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr7\"\>", ",", "574"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr8\"\>", ",", "590"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr9\"\>", ",", "531"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chrX\"\>", ",", "77"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr10\"\>", ",", "654"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr11\"\>", ",", "680"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr12\"\>", ",", "626"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr13\"\>", ",", "285"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr14\"\>", ",", "293"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr15\"\>", ",", "414"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr16\"\>", ",", "516"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr17\"\>", ",", "390"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr18\"\>", ",", "254"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr19\"\>", ",", "399"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr20\"\>", ",", "301"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr21\"\>", ",", "119"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr22\"\>", ",", "243"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_apd_hap1\"\>", ",", "136"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_cox_hap2\"\>", ",", "361"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_dbb_hap3\"\>", ",", "319"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_mcf_hap5\"\>", ",", "292"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_qbl_hap6\"\>", ",", "347"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr4_ctg9_hap1\"\>", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_mann_hap4\"\>", ",", "334"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6_ssto_hap7\"\>", ",", "339"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chrUn_gl000248\"\>", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr17_ctg5_hap1\"\>", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr1_gl000191_random\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr1_gl000192_random\"\>", ",", "1"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.677570989141065*^9}]
}, Open  ]],

Cell[TextData[{
 "Interessant ist nun, diese H\[ADoubleDot]ufigkeit auf die Chromosomenl\
\[ADoubleDot]nge zu normieren. Wir nutzen hierzu die direkte Verbindung von ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " auf die Suchmaschine ",
 StyleBox["WolframAlpha",
  FontSlant->"Italic"],
 ". F\[UDoubleDot]r Chromosom 1 liefert die Suchabfrage sowohl die L\
\[ADoubleDot]nge als auch eine grafische Darstellung des Chromosoms:"
}], "Text",
 CellChangeTimes->{{3.674623486530858*^9, 3.674623509904892*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WolframAlpha", "[", "\"\<human chromosome 1\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.613811608171997*^9, 3.613811612930584*^9}}],

Cell[BoxData[
 NamespaceBox["WolframAlphaQueryResults",
  DynamicModuleBox[{Typeset`q$$ = "human chromosome 1", Typeset`opts$$ = {
   AppearanceElements -> {
     "Warnings", "Assumptions", "Brand", "Pods", "PodMenus", "Unsuccessful", 
      "Sources"}}, Typeset`elements$$ = {
   "Warnings", "Assumptions", "Brand", "Pods", "PodMenus", "Unsuccessful", 
    "Sources"}, Typeset`pod1$$ = XMLElement[
   "pod", {"title" -> "Input interpretation", "scanner" -> "Identity", "id" -> 
     "Input", "position" -> "100", "error" -> "false", "numsubpods" -> "1"}, {
     XMLElement["subpod", {"title" -> ""}, {
       XMLElement["minput", {}, {"GenomeData[\"Chromosome1\"]"}], 
       XMLElement["cell", {"compressed" -> False, "string" -> True}, {
         Cell[
          BoxData[
           FormBox[
            TagBox[
             FormBox[
              TagBox[
               TagBox[
                StyleBox[
                 TemplateBox[{"\"chromosome 1\"", "\"  \"", 
                   StyleBox[
                    
                    RowBox[{
                    "\"(\"", "\[NoBreak]", "\"human\"", "\[NoBreak]", 
                    "\")\""}], {
                    GrayLevel[0.6], 
                    LinebreakAdjustments -> {1, 100, 1, 0, 100}, LineIndent -> 
                    0}, StripOnInput -> False]}, "RowDefault"], LineIndent -> 
                 0], 
                $CellContext`TagBoxWrapper[
                "Entity" -> {$CellContext`GenomeSequenceData, {
                   "Chromosome1", {"Species" -> "HomoSapiens"}}}]], Identity],
               TraditionalForm], 
             PolynomialForm[#, TraditionalOrder -> False]& ], 
            TraditionalForm]], "Output", {}, CellSize -> {550, Automatic}]}], 
       XMLElement[
       "dataformats", {}, {
        "plaintext,minput,computabledata,formatteddata"}]}]}], 
   Typeset`pod2$$ = XMLElement[
   "pod", {"title" -> "Reference sequence length", "scanner" -> "Data", "id" -> 
     "ChromosomeLength:GenomeSequenceData", "position" -> "200", "error" -> 
     "false", "numsubpods" -> "1"}, {
     XMLElement["subpod", {"title" -> ""}, {
       XMLElement["cell", {"compressed" -> False, "string" -> True}, {
         Cell[
          BoxData[
           FormBox[
            StyleBox[
             TagBox[
              RowBox[{
                TagBox[
                 TagBox[
                  RowBox[{
                    TagBox["249.3", 
                    $CellContext`TagBoxWrapper["StringBoxes" -> "249.3"]], 
                    "\[NoBreak]", 
                    StyleBox[
                    RowBox[{}], FontFamily -> "Helvetica", FontSize -> 
                    Smaller], "\[InvisibleSpace]", "\[ThickSpace]", 
                    "\[InvisibleSpace]", 
                    StyleBox[
                    "\"Mbp\"", FontFamily -> "Helvetica", FontSize -> 
                    Smaller]}], Identity], #& , SyntaxForm -> Dot], "  ", 
                StyleBox[
                 
                 RowBox[{
                  "\"(\"", "\[NoBreak]", "\"megabase pairs\"", "\[NoBreak]", 
                   "\")\""}], {FontSize -> Smaller, FontFamily -> "Helvetica", 
                  GrayLevel[0.6], LinebreakAdjustments -> {1, 100, 1, 0, 100},
                   LineIndent -> 0}, StripOnInput -> False]}], "Unit", 
              SyntaxForm -> Dot], LinebreakAdjustments -> {1, 100, 1, 0, 100},
              LineIndent -> 0, ZeroWidthTimes -> False], TraditionalForm]], 
          "Output", {}, CellSize -> {550, Automatic}]}], 
       XMLElement[
       "dataformats", {}, {
        "plaintext,computabledata,formatteddata,numberdata,quantitydata"}]}]}]\
, Typeset`pod3$$ = XMLElement[
   "pod", {"title" -> "Idiogram", "scanner" -> "Data", "id" -> 
     "ChromosomeIdiogram:GenomeSequenceData", "position" -> "300", "error" -> 
     "false", "numsubpods" -> "1"}, {
     XMLElement["subpod", {"title" -> ""}, {
       XMLElement["cell", {"compressed" -> True, "string" -> False}, {
         Cell[
          BoxData[
           FormBox[
            TemplateBox[{
              GraphicsBox[{
                GrayLevel[1], 
                EdgeForm[{
                  GrayLevel[0], 
                  Thickness[0.0015]}], 
                PolygonBox[{{{0.006622516556291391, 0}, {
                   0.005555555555555555, 0}, {0.005555555555555554, 0.}, {
                   0.004590843457405942, 0.00008440137215439975}, {
                   0.00365544364819073, 0.00033504099563384186`}, {
                   0.002777777777777775, 0.0007443033123086754}, {
                   0.001984513279519225, 0.0012997530937834557`}, {
                   0.0012997530937834557`, 0.001984513279519226}, {
                   0.0007443033123086746, 0.002777777777777777}, {
                   0.00033504099563384186`, 0.003655443648190729}, {
                   0.00008440137215439888, 0.004590843457405944}, {0., 
                   0.005555555555555556}, {0., 0.005555555555555555}, {0., 
                   0.016666666666666663`}, {0., 0.016666666666666663`}, {
                   0.00008440137215439975, 0.017631378764816276`}, {
                   0.0003350409956338427, 0.018566778574031488`}, {
                   0.0007443033123086737, 0.01944444444444444}, {
                   0.0012997530937834557`, 0.020237708942702992`}, {
                   0.0019845132795192257`, 0.020922469128438762`}, {
                   0.002777777777777776, 0.021477918909913542`}, {
                   0.003655443648190729, 0.021887181226588375`}, {
                   0.004590843457405942, 0.022137820850067817`}, {
                   0.005555555555555555, 0.02222222222222222}, {
                   0.005555555555555555, 0.02222222222222222}, {
                   0.006622516556291391, 0.02222222222222222}, {
                   0.006622516556291391, 0}}, {{0.006622516556291391, 0}, {
                   0.006622516556291391, 0.02222222222222222}, {
                   0.016158940397350992`, 0.02222222222222222}, {
                   0.016158940397350992`, 0}, {0.006622516556291391, 0}}, {{
                   0.016158940397350992`, 0}, {0.016158940397350992`, 
                   0.02222222222222222}, {0.022781456953642386`, 
                   0.02222222222222222}, {0.022781456953642386`, 0}, {
                   0.016158940397350992`, 0}}, {{0.022781456953642386`, 0}, {
                   0.022781456953642386`, 0.02222222222222222}, {
                   0.030397350993377485`, 0.02222222222222222}, {
                   0.030397350993377485`, 0}, {0.022781456953642386`, 0}}, {{
                   0.030397350993377485`, 0}, {0.030397350993377485`, 
                   0.02222222222222222}, {0.04370860927152318, 
                   0.02222222222222222}, {0.04370860927152318, 0}, {
                   0.030397350993377485`, 0}}, {{0.04370860927152318, 0}, {
                   0.04370860927152318, 0.02222222222222222}, {
                   0.057019867549668875`, 0.02222222222222222}, {
                   0.057019867549668875`, 0}, {0.04370860927152318, 0}}, {{
                   0.057019867549668875`, 0}, {0.057019867549668875`, 
                   0.02222222222222222}, {0.07986754966887417, 
                   0.02222222222222222}, {0.07986754966887417, 0}, {
                   0.057019867549668875`, 0}}, {{0.07986754966887417, 0}, {
                   0.07986754966887417, 0.02222222222222222}, {
                   0.08748344370860928, 0.02222222222222222}, {
                   0.08748344370860928, 0}, {0.07986754966887417, 0}}, {{
                   0.08748344370860928, 0}, {0.08748344370860928, 
                   0.02222222222222222}, {0.10072847682119206`, 
                   0.02222222222222222}, {0.10072847682119206`, 0}, {
                   0.08748344370860928, 0}}, {{0.10072847682119206`, 0}, {
                   0.10072847682119206`, 0.02222222222222222}, {
                   0.10933774834437086`, 0.02222222222222222}, {
                   0.10933774834437086`, 0}, {0.10072847682119206`, 0}}, {{
                   0.10933774834437086`, 0}, {0.10933774834437086`, 
                   0.02222222222222222}, {0.11788079470198676`, 
                   0.02222222222222222}, {0.11788079470198676`, 0}, {
                   0.10933774834437086`, 0}}, {{0.11788079470198676`, 0}, {
                   0.11788079470198676`, 0.02222222222222222}, {
                   0.12549668874172185`, 0.02222222222222222}, {
                   0.12549668874172185`, 0}, {0.11788079470198676`, 0}}, {{
                   0.12549668874172185`, 0}, {0.12549668874172185`, 
                   0.02222222222222222}, {0.14635761589403973`, 
                   0.02222222222222222}, {0.14635761589403973`, 0}, {
                   0.12549668874172185`, 0}}, {{0.14635761589403973`, 0}, {
                   0.14635761589403973`, 0.02222222222222222}, {
                   0.15966887417218542`, 0.02222222222222222}, {
                   0.15966887417218542`, 0}, {0.14635761589403973`, 0}}, {{
                   0.15966887417218542`, 0}, {0.15966887417218542`, 
                   0.02222222222222222}, {0.18344370860927153`, 
                   0.02222222222222222}, {0.18344370860927153`, 0}, {
                   0.15966887417218542`, 0}}, {{0.18344370860927153`, 0}, {
                   0.18344370860927153`, 0.02222222222222222}, {
                   0.19774834437086092`, 0.02222222222222222}, {
                   0.19774834437086092`, 0}, {0.18344370860927153`, 0}}, {{
                   0.19774834437086092`, 0}, {0.19774834437086092`, 
                   0.02222222222222222}, {0.21675496688741722`, 
                   0.02222222222222222}, {0.21675496688741722`, 0}, {
                   0.19774834437086092`, 0}}, {{0.21675496688741722`, 0}, {
                   0.21675496688741722`, 0.02222222222222222}, {
                   0.22622516556291392`, 0.02222222222222222}, {
                   0.22622516556291392`, 0}, {0.21675496688741722`, 0}}, {{
                   0.22622516556291392`, 0}, {0.22622516556291392`, 
                   0.02222222222222222}, {0.2471523178807947, 
                   0.02222222222222222}, {0.2471523178807947, 0}, {
                   0.22622516556291392`, 0}}, {{0.2471523178807947, 0}, {
                   0.2471523178807947, 0.02222222222222222}, {
                   0.2633112582781457, 0.02222222222222222}, {
                   0.2633112582781457, 0}, {0.2471523178807947, 0}}, {{
                   0.2633112582781457, 0}, {0.2633112582781457, 
                   0.02222222222222222}, {0.2785430463576159, 
                   0.02222222222222222}, {0.2785430463576159, 0}, {
                   0.2633112582781457, 0}}, {{0.2785430463576159, 0}, {
                   0.2785430463576159, 0.02222222222222222}, {
                   0.3213245033112583, 0.02222222222222222}, {
                   0.3213245033112583, 0}, {0.2785430463576159, 0}}, {{
                   0.3213245033112583, 0}, {0.3213245033112583, 
                   0.02222222222222222}, {0.34503311258278146`, 
                   0.02222222222222222}, {0.34503311258278146`, 0}, {
                   0.3213245033112583, 0}}, {{0.34503311258278146`, 0}, {
                   0.34503311258278146`, 0.02222222222222222}, {
                   0.36026490066225164`, 0.02222222222222222}, {
                   0.36026490066225164`, 0}, {0.34503311258278146`, 0}}, {{
                   0.36026490066225164`, 0}, {0.36026490066225164`, 
                   0.02222222222222222}, {0.38019867549668873`, 
                   0.02222222222222222}, {0.38019867549668873`, 0}, {
                   0.36026490066225164`, 0}}, {{0.38019867549668873`, 0}, {
                   0.38019867549668873`, 0.02222222222222222}, {
                   0.39450331125827814`, 0.02222222222222222}, {
                   0.39450331125827814`, 0}, {0.38019867549668873`, 0}}, {{
                   0.39450331125827814`, 0}, {0.39450331125827814`, 
                   0.02222222222222222}, {0.39927152317880793`, 
                   0.02222222222222222}, {0.39927152317880793`, 0}, {
                   0.39450331125827814`, 0}}, {{0.39927152317880793`, 0}, {
                   0.39927152317880793`, 0.02222222222222222}, {
                   0.4135099337748344, 0.02222222222222222}, {
                   0.4135099337748344, 0}, {0.39927152317880793`, 0}}, {{
                   0.4135099337748344, 0}, {0.4135099337748344, 
                   0.02222222222222222}, {0.4277483443708609, 
                   0.02222222222222222}, {0.4277483443708609, 0}, {
                   0.4135099337748344, 0}}, {{0.4277483443708609, 0}, {
                   0.4277483443708609, 0.02222222222222222}, {
                   0.4410596026490066, 0.02222222222222222}, {
                   0.4410596026490066, 0}, {0.4277483443708609, 0}}, {{
                   0.4410596026490066, 0}, {0.4410596026490066, 
                   0.02222222222222222}, {0.45437086092715234`, 
                   0.02222222222222222}, {0.45437086092715234`, 0}, {
                   0.4410596026490066, 0}}, {{0.45437086092715234`, 0}, {
                   0.45437086092715234`, 0.02222222222222222}, {
                   0.46675496688741724`, 0.02222222222222222}, {
                   0.46675496688741724`, 0}, {0.45437086092715234`, 0}}, {{
                   0.46675496688741724`, 0}, {0.46675496688741724`, 
                   0.02222222222222222}, {0.4714569536423841, 
                   0.02222222222222222}, {0.4714569536423841, 0}, {
                   0.46675496688741724`, 0}}, {{0.4714569536423841, 0}, {
                   0.4714569536423841, 0.02222222222222222}, {
                   0.4746504782928624, 0.02222222222222222}, {
                   0.4746504782928624, 0.02222222222222222}, {
                   0.4765799024891616, 0.022053419477913422`}, {
                   0.47845070210759205`, 0.021552140230954534`}, {
                   0.4802060338484179, 0.020733615597604872`}, {
                   0.48179256284493505`, 0.019622716034655308`}, {
                   0.4831620832164066, 0.018253195663183768`}, {
                   0.48427298277935615`, 0.016666666666666663`}, {
                   0.4850915074127058, 0.014911334925840762`}, {
                   0.4855927866596647, 0.013040535307410336`}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4855927866596647, 0.009181686914811884}, {
                   0.4850915074127058, 0.007310887296381458}, {
                   0.48427298277935615`, 0.005555555555555556}, {
                   0.4831620832164066, 0.003969026559038452}, {
                   0.48179256284493505`, 0.0025995061875669113`}, {
                   0.4802060338484179, 0.0014886066246173491`}, {
                   0.47845070210759205`, 0.0006700819912676854}, {
                   0.4765799024891616, 0.0001688027443087995}, {
                   0.4746504782928624, 0.}, {0.4746504782928624, 0}, {
                   0.4714569536423841, 0}}, {{0.5019205298013245, 0}, {
                   0.49687270051508464`, 0}, {0.49687270051508464`, 0.}, {
                   0.49494327631878543`, 0.0001688027443087995}, {
                   0.493072476700355, 0.0006700819912676837}, {
                   0.4913171449595291, 0.0014886066246173509`}, {
                   0.489730615963012, 0.0025995061875669113`}, {
                   0.48836109559154045`, 0.003969026559038452}, {
                   0.4872501960285909, 0.005555555555555554}, {
                   0.48643167139524124`, 0.007310887296381458}, {
                   0.4859303921482823, 0.009181686914811887}, {
                   0.4857615894039735, 0.011111111111111112`}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4857615894039735, 0.01111111111111111}, {
                   0.4857615894039735, 0.011111111111111112`}, {
                   0.4859303921482823, 0.013040535307410336`}, {
                   0.48643167139524124`, 0.014911334925840763`}, {
                   0.4872501960285909, 0.016666666666666663`}, {
                   0.48836109559154045`, 0.01825319566318377}, {
                   0.489730615963012, 0.019622716034655308`}, {
                   0.4913171449595291, 0.020733615597604872`}, {
                   0.493072476700355, 0.021552140230954538`}, {
                   0.49494327631878543`, 0.022053419477913422`}, {
                   0.49687270051508464`, 0.02222222222222222}, {
                   0.49687270051508464`, 0.02222222222222222}, {
                   0.5019205298013245, 0.02222222222222222}, {
                   0.5019205298013245, 0}}, {{0.5019205298013245, 0}, {
                   0.5019205298013245, 0.02222222222222222}, {
                   0.5617880794701987, 0.02222222222222222}, {
                   0.5617880794701987, 0}, {0.5019205298013245, 0}}, {{
                   0.5617880794701987, 0}, {0.5617880794701987, 
                   0.02222222222222222}, {0.5798675496688742, 
                   0.02222222222222222}, {0.5798675496688742, 0}, {
                   0.5617880794701987, 0}}, {{0.5798675496688742, 0}, {
                   0.5798675496688742, 0.02222222222222222}, {
                   0.5931788079470198, 0.02222222222222222}, {
                   0.5931788079470198, 0}, {0.5798675496688742, 0}}, {{
                   0.5931788079470198, 0}, {0.5931788079470198, 
                   0.02222222222222222}, {0.6121854304635762, 
                   0.02222222222222222}, {0.6121854304635762, 0}, {
                   0.5931788079470198, 0}}, {{0.6121854304635762, 0}, {
                   0.6121854304635762, 0.02222222222222222}, {
                   0.6264238410596027, 0.02222222222222222}, {
                   0.6264238410596027, 0}, {0.6121854304635762, 0}}, {{
                   0.6264238410596027, 0}, {0.6264238410596027, 
                   0.02222222222222222}, {0.6511258278145695, 
                   0.02222222222222222}, {0.6511258278145695, 0}, {
                   0.6264238410596027, 0}}, {{0.6511258278145695, 0}, {
                   0.6511258278145695, 0.02222222222222222}, {
                   0.665430463576159, 0.02222222222222222}, {
                   0.665430463576159, 0}, {0.6511258278145695, 0}}, {{
                   0.665430463576159, 0}, {0.665430463576159, 
                   0.02222222222222222}, {0.685364238410596, 
                   0.02222222222222222}, {0.685364238410596, 0}, {
                   0.665430463576159, 0}}, {{0.685364238410596, 0}, {
                   0.685364238410596, 0.02222222222222222}, {
                   0.6958278145695365, 0.02222222222222222}, {
                   0.6958278145695365, 0}, {0.685364238410596, 0}}, {{
                   0.6958278145695365, 0}, {0.6958278145695365, 
                   0.02222222222222222}, {0.7072185430463576, 
                   0.02222222222222222}, {0.7072185430463576, 0}, {
                   0.6958278145695365, 0}}, {{0.7072185430463576, 0}, {
                   0.7072185430463576, 0.02222222222222222}, {
                   0.7214569536423842, 0.02222222222222222}, {
                   0.7214569536423842, 0}, {0.7072185430463576, 0}}, {{
                   0.7214569536423842, 0}, {0.7214569536423842, 
                   0.02222222222222222}, {0.7290728476821192, 
                   0.02222222222222222}, {0.7290728476821192, 0}, {
                   0.7214569536423842, 0}}, {{0.7290728476821192, 0}, {
                   0.7290728476821192, 0.02222222222222222}, {
                   0.7414569536423841, 0.02222222222222222}, {
                   0.7414569536423841, 0}, {0.7290728476821192, 0}}, {{
                   0.7414569536423841, 0}, {0.7414569536423841, 
                   0.02222222222222222}, {0.7680794701986755, 
                   0.02222222222222222}, {0.7680794701986755, 0}, {
                   0.7414569536423841, 0}}, {{0.7680794701986755, 0}, {
                   0.7680794701986755, 0.02222222222222222}, {
                   0.7832450331125828, 0.02222222222222222}, {
                   0.7832450331125828, 0}, {0.7680794701986755, 0}}, {{
                   0.7832450331125828, 0}, {0.7832450331125828, 
                   0.02222222222222222}, {0.7908609271523179, 
                   0.02222222222222222}, {0.7908609271523179, 0}, {
                   0.7832450331125828, 0}}, {{0.7908609271523179, 0}, {
                   0.7908609271523179, 0.02222222222222222}, {
                   0.806092715231788, 0.02222222222222222}, {
                   0.806092715231788, 0}, {0.7908609271523179, 0}}, {{
                   0.806092715231788, 0}, {0.806092715231788, 
                   0.02222222222222222}, {0.8355629139072848, 
                   0.02222222222222222}, {0.8355629139072848, 0}, {
                   0.806092715231788, 0}}, {{0.8355629139072848, 0}, {
                   0.8355629139072848, 0.02222222222222222}, {
                   0.8478807947019867, 0.02222222222222222}, {
                   0.8478807947019867, 0}, {0.8355629139072848, 0}}, {{
                   0.8478807947019867, 0}, {0.8478807947019867, 
                   0.02222222222222222}, {0.863112582781457, 
                   0.02222222222222222}, {0.863112582781457, 0}, {
                   0.8478807947019867, 0}}, {{0.863112582781457, 0}, {
                   0.863112582781457, 0.02222222222222222}, {
                   0.8821192052980132, 0.02222222222222222}, {
                   0.8821192052980132, 0}, {0.863112582781457, 0}}, {{
                   0.8821192052980132, 0}, {0.8821192052980132, 
                   0.02222222222222222}, {0.8878145695364238, 
                   0.02222222222222222}, {0.8878145695364238, 0}, {
                   0.8821192052980132, 0}}, {{0.8878145695364238, 0}, {
                   0.8878145695364238, 0.02222222222222222}, {
                   0.9011258278145695, 0.02222222222222222}, {
                   0.9011258278145695, 0}, {0.8878145695364238, 0}}, {{
                   0.9011258278145695, 0}, {0.9011258278145695, 
                   0.02222222222222222}, {0.9249006622516557, 
                   0.02222222222222222}, {0.9249006622516557, 0}, {
                   0.9011258278145695, 0}}, {{0.9249006622516557, 0}, {
                   0.9249006622516557, 0.02222222222222222}, {
                   0.9372847682119205, 0.02222222222222222}, {
                   0.9372847682119205, 0}, {0.9249006622516557, 0}}, {{
                   0.9372847682119205, 0}, {0.9372847682119205, 
                   0.02222222222222222}, {0.9534437086092715, 
                   0.02222222222222222}, {0.9534437086092715, 0}, {
                   0.9372847682119205, 0}}, {{0.9534437086092715, 0}, {
                   0.9534437086092715, 0.02222222222222222}, {
                   0.9772185430463576, 0.02222222222222222}, {
                   0.9772185430463576, 0}, {0.9534437086092715, 0}}, {{
                   0.9772185430463576, 0}, {0.9772185430463576, 
                   0.02222222222222222}, {0.9944444444444445, 
                   0.02222222222222222}, {0.9944444444444445, 
                   0.02222222222222222}, {0.9954091565425941, 
                   0.022137820850067817`}, {0.9963445563518093, 
                   0.021887181226588375`}, {0.9972222222222222, 
                   0.021477918909913546`}, {0.9980154867204808, 
                   0.020922469128438762`}, {0.9987002469062166, 
                   0.020237708942702992`}, {0.9992556966876913, 
                   0.01944444444444444}, {0.9996649590043661, 
                   0.018566778574031488`}, {0.9999155986278456, 
                   0.017631378764816276`}, {1., 0.016666666666666663`}, {1., 
                   0.016666666666666663`}, {1., 0.005555555555555555}, {1., 
                   0.005555555555555555}, {0.9999155986278456, 
                   0.004590843457405942}, {0.9996649590043661, 
                   0.003655443648190729}, {0.9992556966876913, 
                   0.002777777777777778}, {0.9987002469062166, 
                   0.001984513279519226}, {0.9980154867204808, 
                   0.0012997530937834557`}, {0.9972222222222222, 
                   0.0007443033123086746}, {0.9963445563518093, 
                   0.0003350409956338427}, {0.9954091565425941, 
                   0.00008440137215439975}, {0.9944444444444445, 0.}, {
                   0.9944444444444445, 0}, {0.9772185430463576, 0}}}, 
                 VertexColors -> {{1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
                    1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
                   1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 
                   1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 
                   1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {
                   0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75,
                    0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 
                   0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75,
                    0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 
                   0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
                   0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 
                   0.5}, {1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 
                   1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 
                   1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
                   1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.5, 0.5,
                    0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5,
                    0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25,
                    0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
                   0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
                    0.25, 0.25, 0.25}, {0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
                   0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
                    0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
                   0.25, 0.25}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 
                   1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5,
                    0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5,
                    0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 
                   0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 
                   0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
                   1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1.,
                    1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 
                   0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0., 0., 0.,
                    0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 
                   0.75}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
                   1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 
                   1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
                    1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}}], 
                EdgeForm[None], 
                RGBColor[1, 0, 0], 
                PolygonBox[{}]}, Frame -> {{False, False}, {True, False}}, 
               FrameTicks -> {{None, None}, {{{0., 
                    FormBox["\"0 Mb\"", TraditionalForm]}, {
                   0.12133481939366733`, 
                    FormBox["\"30 Mb\"", TraditionalForm]}, {
                   0.24266963878733466`, 
                    FormBox["\"60 Mb\"", TraditionalForm]}, {
                   0.364004458181002, 
                    FormBox["\"90 Mb\"", TraditionalForm]}, {
                   0.4853392775746693, 
                    FormBox["\"120 Mb\"", TraditionalForm]}, {
                   0.6066740969683367, 
                    FormBox["\"150 Mb\"", TraditionalForm]}, {
                   0.728008916362004, 
                    FormBox["\"180 Mb\"", TraditionalForm]}, {
                   0.8493437357556713, 
                    FormBox["\"210 Mb\"", TraditionalForm]}, {
                   0.9706785551493387, 
                    FormBox["\"240 Mb\"", TraditionalForm]}}, None}}, 
               FrameStyle -> {{None, None}, {
                  GrayLevel[0.5], None}}, ImageSize -> 450, AspectRatio -> 
               Automatic, 
               ImagePadding -> {{10, Automatic}, {Automatic, Automatic}}], 
              StyleBox["\"chromosome 1\"", {
                GrayLevel[0.6], LinebreakAdjustments -> {1, 100, 1, 0, 100}, 
                LineIndent -> 0}, StripOnInput -> False]}, "Labeled", 
             DisplayFunction -> (FormBox[
               GridBox[{{
                  
                  ItemBox[#2, Alignment -> {Left, Inherited}, 
                   DefaultBaseStyle -> "LabeledLabel"]}, {
                  TagBox[
                   ItemBox[
                    PaneBox[
                    TagBox[#, "SkipImageSizeLevel"], 
                    Alignment -> {Center, Baseline}, BaselinePosition -> 
                    Baseline], DefaultBaseStyle -> "Labeled"], 
                   "SkipImageSizeLevel"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                BaselinePosition -> {2, 1}], TraditionalForm]& ), 
             InterpretationFunction -> (RowBox[{
                StyleBox[
                "Labeled", FontFamily -> "Bitstream Vera Sans", 
                 FontSize -> -1 + Inherited], "[", 
                RowBox[{#, ",", #2, ",", 
                  RowBox[{"(", "\[NoBreak]", 
                    GridBox[{{
                    StyleBox[
                    "Top", FontFamily -> "Bitstream Vera Sans", 
                    FontSize -> -1 + Inherited], 
                    StyleBox[
                    "Left", FontFamily -> "Bitstream Vera Sans", 
                    FontSize -> -1 + Inherited]}}, RowSpacings -> 1, 
                    ColumnSpacings -> 1, RowAlignments -> Baseline, 
                    ColumnAlignments -> Center], "\[NoBreak]", ")"}]}], 
                "]"}]& )], TraditionalForm]], "Output", {}, 
          CellSize -> {550, Automatic}]}], 
       XMLElement["dataformats", {}, {"computabledata,formatteddata"}]}]}], 
   Typeset`aux1$$ = {True, False, {False}, True}, Typeset`aux2$$ = {
   True, False, {False}, True}, Typeset`aux3$$ = {True, False, {False}, True},
    Typeset`asyncpods$$ = {}, Typeset`nonpods$$ = {
    XMLElement["sources", {"count" -> "2"}, {
      XMLElement[
      "source", {
       "url" -> 
        "http://www.wolframalpha.com/sources/GenomeDataSourceInformationNotes.\
html", "text" -> "Genome data"}, {}], 
      XMLElement[
      "source", {
       "url" -> 
        "http://www.wolframalpha.com/sources/\
GenomeSequenceDataSourceInformationNotes.html", "text" -> 
        "Genome sequence data"}, {}]}]}, Typeset`initdone$$ = True, 
   Typeset`queryinfo$$ = {
   "success" -> "true", "error" -> "false", "numpods" -> "3", "datatypes" -> 
    "GenomeSequence", "timedout" -> "", "timedoutpods" -> "", "timing" -> 
    "0.679", "parsetiming" -> "0.208", "parsetimedout" -> "false", 
    "recalculate" -> "", "id" -> 
    "MSPa9971e04760i39f7dd9800002ieh59d3fai7ihh7", "host" -> 
    "http://www4f.wolframalpha.com", "server" -> "60", "related" -> 
    "http://www4f.wolframalpha.com/api/v2/relatedQueries.jsp?id=\
MSPa9981e04760i39f7dd98000017b08d64a5bd4bdd7294925898220232356", "version" -> 
    "2.6"}, Typeset`sessioninfo$$ = {
   "TimeZone" -> 2., 
    "Date" -> {2016, 7, 15, 13, 29, 54.0862738`9.485661904220558}, "Line" -> 
    8, "SessionID" -> 20770180981562572811}, Typeset`showpods$$ = {1, 2, 3}, 
   Typeset`failedpods$$ = {}, Typeset`chosen$$ = {}, Typeset`open$$ = False, 
   Typeset`newq$$ = "human chromosome 1"}, 
   DynamicBox[ToBoxes[
     AlphaIntegration`FormatAlphaResults[
      Dynamic[{
       1, {Typeset`pod1$$, Typeset`pod2$$, Typeset`pod3$$}, {
        Typeset`aux1$$, Typeset`aux2$$, Typeset`aux3$$}, Typeset`chosen$$, 
        Typeset`open$$, Typeset`elements$$, Typeset`q$$, Typeset`opts$$, 
        Typeset`nonpods$$, Typeset`queryinfo$$, Typeset`sessioninfo$$, 
        Typeset`showpods$$, Typeset`failedpods$$, Typeset`newq$$}]], 
     StandardForm],
    ImageSizeCache->{385., {126., 133.}},
    TrackedSymbols:>{Typeset`showpods$$, Typeset`failedpods$$}],
   DynamicModuleValues:>{},
   Initialization:>If[
     Not[Typeset`initdone$$], Null; WolframAlphaClient`Private`doAsyncUpdates[
       Hold[{Typeset`pod1$$, Typeset`pod2$$, Typeset`pod3$$}], 
       Typeset`asyncpods$$, 
       Dynamic[Typeset`failedpods$$]]; Typeset`asyncpods$$ = {}; 
     Typeset`initdone$$ = True],
   SynchronousInitialization->False],
  BaseStyle->{Deployed -> True},
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True]], "Output",
 CellChangeTimes->{3.677570994569875*^9}]
}, Open  ]],

Cell["\<\
Das Resultat ist in Abb. 2.27 angegeben. Die L\[ADoubleDot]ngen \
f\[UDoubleDot]r alle Chromosomen lassen sich auch direkt abfragen:\
\>", "Text",
 CellChangeTimes->{{3.6746235392619343`*^9, 3.6746235567849627`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WolframAlpha", "[", 
  RowBox[{"\"\<human chromosome 1\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}], 
      "}"}], ",", "\"\<ComputableData\>\""}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{"249.3`",RowBox[{
     FrameBox[
      StyleBox["\"megabase pairs\"", ShowStringCharacters -> False], 
      FrameMargins -> 1, FrameStyle -> GrayLevel[0.85], BaselinePosition -> 
      Baseline, RoundingRadius -> 3, StripOnInput -> False]}],
   "megabase pairs",
   RowBox[{"IndependentUnit", "[", "\"megabase pairs\"", "]"}]},
  "Quantity"]], "Output",
 CellChangeTimes->{3.677570996644678*^9}]
}, Open  ]],

Cell[TextData[{
 "\[CapitalUDoubleDot]ber diesen Weg k\[ODoubleDot]nnen wir eine Liste der \
Chromosomenl\[ADoubleDot]ngen erstellen. Dabei erzeugen wir (mit dem Befehl ",
 StyleBox["ToString[k]",
  FontWeight->"Bold"],
 ") den Sucheintrag direkt aus dem Laufindex. Das X-Chromosom \
f\[UDoubleDot]gen wir separat an."
}], "Text",
 CellChangeTimes->{{3.6746237381592283`*^9, 3.6746237754612837`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tabLength", " ", "=", " ", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<chr\>\"", "<>", 
         RowBox[{"ToString", "[", "k", "]"}]}], ",", 
        RowBox[{
         RowBox[{"WolframAlpha", "[", 
          RowBox[{
           RowBox[{"\"\<human chromosome \>\"", "<>", 
            RowBox[{"ToString", "[", "k", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}], 
              "}"}], ",", "\"\<NumberData\>\""}], "}"}]}], "]"}], "*", 
         "1000000"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "21", ",", "1"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<chrX\>\"", ",", 
      RowBox[{
       RowBox[{"WolframAlpha", "[", 
        RowBox[{"\"\<human chromosome X\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}],
             "}"}], ",", "\"\<NumberData\>\""}], "}"}]}], "]"}], "*", 
       "1000000"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613961073184614*^9, 3.6139610959020653`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"chr1\"\>", ",", "2.493`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr2\"\>", ",", "243000000"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr3\"\>", ",", "1.995`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr4\"\>", ",", "1.913`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr5\"\>", ",", "1.809`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr6\"\>", ",", "1.709`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr7\"\>", ",", "1.588`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr8\"\>", ",", "1.463`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr9\"\>", ",", "1.403`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr10\"\>", ",", "1.354`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr11\"\>", ",", "1.345`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr12\"\>", ",", "1.3230000000000001`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr13\"\>", ",", "1.141`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr14\"\>", ",", "1.064`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr15\"\>", ",", "1.003`*^8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr16\"\>", ",", "8.883`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr17\"\>", ",", "7.877`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr18\"\>", ",", "7.612`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr19\"\>", ",", "6.381`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr20\"\>", ",", "6.244`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chr21\"\>", ",", "4.694`*^7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"chrX\"\>", ",", "1.549`*^8"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6775710177515154`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die oben mit ",
 StyleBox["Tally",
  FontWeight->"Bold"],
 " erzeugte H\[ADoubleDot]ufigkeitsliste k\[ODoubleDot]nnen wir nun in eine \
\[CapitalUDoubleDot]bersetzungsvorschrift verwandeln und den Quotienten mit \
der L\[ADoubleDot]nge bilden. Die grafische Darstellung dieser neuen Liste \
zeigt dann die Unterschiede der SNP-Dichten zwischen den Chromosomen:"
}], "Text",
 CellChangeTimes->{{3.674623837045373*^9, 3.674623865132415*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabLength2", " ", "=", " ", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tabLength", " ", "/.", " ", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"k1_", ",", "k2_"}], "}"}], "\[Rule]", " ", "k1"}]}], ",", 
       RowBox[{"tabLength", " ", "/.", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"Tally", "[", 
           RowBox[{"gwas2", " ", "/.", " ", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", "n1"}]}], "]"}], 
          " ", "/.", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"nn1_String", ",", "nn2_"}], "}"}], "\[Rule]", " ", 
           RowBox[{"(", 
            RowBox[{"nn1", "\[Rule]", " ", "nn2"}], ")"}]}]}], ")"}]}]}], 
      "}"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kk1_", ",", 
       RowBox[{"{", 
        RowBox[{"kk2_", ",", "kk3_"}], "}"}]}], "}"}], "\[RuleDelayed]", "  ", 
     RowBox[{"{", 
      RowBox[{"kk1", ",", 
       RowBox[{"N", "[", 
        RowBox[{"kk2", "/", "kk3"}], "]"}]}], "}"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613961248433845*^9, 3.613961398884329*^9}, 
   3.613963141931033*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"tabLength2", " ", "/.", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", 
     RowBox[{
      RowBox[{"10", "^", "6"}], "n2"}]}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"AbsolutePointSize", "[", "5", "]"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{"k", ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1", ",", 
               RowBox[{"Length", "[", "tabLength", "]"}]}], "}"}]}], "]"}], 
           ",", 
           RowBox[{"tabLength2", " ", "/.", " ", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", "n1"}]}]}], 
          "}"}], "]"}], ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "0.2"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
   RowBox[{"FrameTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "10", ",", "Plain"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613961402765028*^9, 3.613961470971676*^9}, {
  3.613961503153492*^9, 3.613961540119326*^9}, {3.6139615755916367`*^9, 
  3.613961670203672*^9}, {3.61396316470763*^9, 3.61396323196073*^9}, {
  3.6228828583812933`*^9, 3.6228828589985723`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {GrayLevel[0], AbsolutePointSize[5], AbsoluteThickness[1.6], 
     PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7P+rLnObYC/oABVw+C50yztDH8bncOjbZ/nr
2QtuKF/AYfPaew1PS9mhfBGHb7M0rURP8UD5Eg5MLkkGgaukoXwZBz+50Jwd
r2DyCg4ee6YcmqEoAOUrOcz9WZGt6c4H5as4PHrUEccXJAzlqzlsr/62UdJS
BMrXcEgNLmaxfisE5Ws53Ei+7tD8mxnK13GoPvCGcTM7G5Sv51B05q7guiaY
fQYOfZ079znZiEP5hg63/K2DP5+F2WfkUDdzafz1jVxQvrFD6v8sTyZmSSjf
xMHp16zlQR4w9aYO602uJ/51Z4HyzRzmnepTSL9w3x4AsTJW4Q==
      "]]}, {}}, {}},
  AspectRatio->0.2,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{1, 
       FormBox["\"chr1\"", TraditionalForm]}, {2, 
       FormBox["\"chr2\"", TraditionalForm]}, {3, 
       FormBox["\"chr3\"", TraditionalForm]}, {4, 
       FormBox["\"chr4\"", TraditionalForm]}, {5, 
       FormBox["\"chr5\"", TraditionalForm]}, {6, 
       FormBox["\"chr6\"", TraditionalForm]}, {7, 
       FormBox["\"chr7\"", TraditionalForm]}, {8, 
       FormBox["\"chr8\"", TraditionalForm]}, {9, 
       FormBox["\"chr9\"", TraditionalForm]}, {10, 
       FormBox["\"chr10\"", TraditionalForm]}, {11, 
       FormBox["\"chr11\"", TraditionalForm]}, {12, 
       FormBox["\"chr12\"", TraditionalForm]}, {13, 
       FormBox["\"chr13\"", TraditionalForm]}, {14, 
       FormBox["\"chr14\"", TraditionalForm]}, {15, 
       FormBox["\"chr15\"", TraditionalForm]}, {16, 
       FormBox["\"chr16\"", TraditionalForm]}, {17, 
       FormBox["\"chr17\"", TraditionalForm]}, {18, 
       FormBox["\"chr18\"", TraditionalForm]}, {19, 
       FormBox["\"chr19\"", TraditionalForm]}, {20, 
       FormBox["\"chr20\"", TraditionalForm]}, {21, 
       FormBox["\"chr21\"", TraditionalForm]}, {22, 
       FormBox["\"chrX\"", TraditionalForm]}}, Automatic}},
  FrameTicksStyle->Directive[
    GrayLevel[0], 10, Plain],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->600,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 22.}, {0, 6.916325336454067}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677571018125916*^9}]
}, Open  ]],

Cell[TextData[{
 "Dies f\[UDoubleDot]hrt auf Abb. 2.28.\n\nAls N\[ADoubleDot]chstes wollen \
wir uns die lokale H\[ADoubleDot]ufigkeit von SNPs entlang eines Chromosoms \
ansehen. Dazu k\[ODoubleDot]nnen wir die Abbildungen der Chromosomen aus ",
 StyleBox["WolframAlpha",
  FontSlant->"Italic"],
 " nutzen:"
}], "Text",
 CellChangeTimes->{{3.6746238754114304`*^9, 3.6746239075994787`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"temp1", " ", "=", " ", 
  RowBox[{"WolframAlpha", "[", 
   RowBox[{"\"\<human chromosome 1 ideogram\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<Result\>\"", ",", "1"}], "}"}], ",", "\"\<Content\>\""}], 
     "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61380912293648*^9, 3.61380912538165*^9}}],

Cell[BoxData[
 StyleBox[
  FormBox[
   TemplateBox[{GraphicsBox[{
       GrayLevel[1], 
       EdgeForm[{
         GrayLevel[0], 
         Thickness[0.0015]}], 
       PolygonBox[{{{0.006622516556291391, 0}, {0.005555555555555555, 0}, {
          0.005555555555555554, 0.}, {0.004590843457405942, 
          0.00008440137215439975}, {0.00365544364819073, 
          0.00033504099563384186`}, {0.002777777777777775, 
          0.0007443033123086754}, {0.001984513279519225, 
          0.0012997530937834557`}, {0.0012997530937834557`, 
          0.001984513279519226}, {0.0007443033123086746, 
          0.002777777777777777}, {0.00033504099563384186`, 
          0.003655443648190729}, {0.00008440137215439888, 
          0.004590843457405944}, {0., 0.005555555555555556}, {0., 
          0.005555555555555555}, {0., 0.016666666666666663`}, {0., 
          0.016666666666666663`}, {0.00008440137215439975, 
          0.017631378764816276`}, {0.0003350409956338427, 
          0.018566778574031488`}, {0.0007443033123086737, 
          0.01944444444444444}, {0.0012997530937834557`, 
          0.020237708942702992`}, {0.0019845132795192257`, 
          0.020922469128438762`}, {0.002777777777777776, 
          0.021477918909913542`}, {0.003655443648190729, 
          0.021887181226588375`}, {0.004590843457405942, 
          0.022137820850067817`}, {0.005555555555555555, 
          0.02222222222222222}, {0.005555555555555555, 0.02222222222222222}, {
          0.006622516556291391, 0.02222222222222222}, {
          0.006622516556291391, 0}}, {{0.006622516556291391, 0}, {
          0.006622516556291391, 0.02222222222222222}, {0.016158940397350992`, 
          0.02222222222222222}, {0.016158940397350992`, 0}, {
          0.006622516556291391, 0}}, {{0.016158940397350992`, 0}, {
          0.016158940397350992`, 0.02222222222222222}, {0.022781456953642386`,
           0.02222222222222222}, {0.022781456953642386`, 0}, {
          0.016158940397350992`, 0}}, {{0.022781456953642386`, 0}, {
          0.022781456953642386`, 0.02222222222222222}, {0.030397350993377485`,
           0.02222222222222222}, {0.030397350993377485`, 0}, {
          0.022781456953642386`, 0}}, {{0.030397350993377485`, 0}, {
          0.030397350993377485`, 0.02222222222222222}, {0.04370860927152318, 
          0.02222222222222222}, {0.04370860927152318, 0}, {
          0.030397350993377485`, 0}}, {{0.04370860927152318, 0}, {
          0.04370860927152318, 0.02222222222222222}, {0.057019867549668875`, 
          0.02222222222222222}, {0.057019867549668875`, 0}, {
          0.04370860927152318, 0}}, {{0.057019867549668875`, 0}, {
          0.057019867549668875`, 0.02222222222222222}, {0.07986754966887417, 
          0.02222222222222222}, {0.07986754966887417, 0}, {
          0.057019867549668875`, 0}}, {{0.07986754966887417, 0}, {
          0.07986754966887417, 0.02222222222222222}, {0.08748344370860928, 
          0.02222222222222222}, {0.08748344370860928, 0}, {
          0.07986754966887417, 0}}, {{0.08748344370860928, 0}, {
          0.08748344370860928, 0.02222222222222222}, {0.10072847682119206`, 
          0.02222222222222222}, {0.10072847682119206`, 0}, {
          0.08748344370860928, 0}}, {{0.10072847682119206`, 0}, {
          0.10072847682119206`, 0.02222222222222222}, {0.10933774834437086`, 
          0.02222222222222222}, {0.10933774834437086`, 0}, {
          0.10072847682119206`, 0}}, {{0.10933774834437086`, 0}, {
          0.10933774834437086`, 0.02222222222222222}, {0.11788079470198676`, 
          0.02222222222222222}, {0.11788079470198676`, 0}, {
          0.10933774834437086`, 0}}, {{0.11788079470198676`, 0}, {
          0.11788079470198676`, 0.02222222222222222}, {0.12549668874172185`, 
          0.02222222222222222}, {0.12549668874172185`, 0}, {
          0.11788079470198676`, 0}}, {{0.12549668874172185`, 0}, {
          0.12549668874172185`, 0.02222222222222222}, {0.14635761589403973`, 
          0.02222222222222222}, {0.14635761589403973`, 0}, {
          0.12549668874172185`, 0}}, {{0.14635761589403973`, 0}, {
          0.14635761589403973`, 0.02222222222222222}, {0.15966887417218542`, 
          0.02222222222222222}, {0.15966887417218542`, 0}, {
          0.14635761589403973`, 0}}, {{0.15966887417218542`, 0}, {
          0.15966887417218542`, 0.02222222222222222}, {0.18344370860927153`, 
          0.02222222222222222}, {0.18344370860927153`, 0}, {
          0.15966887417218542`, 0}}, {{0.18344370860927153`, 0}, {
          0.18344370860927153`, 0.02222222222222222}, {0.19774834437086092`, 
          0.02222222222222222}, {0.19774834437086092`, 0}, {
          0.18344370860927153`, 0}}, {{0.19774834437086092`, 0}, {
          0.19774834437086092`, 0.02222222222222222}, {0.21675496688741722`, 
          0.02222222222222222}, {0.21675496688741722`, 0}, {
          0.19774834437086092`, 0}}, {{0.21675496688741722`, 0}, {
          0.21675496688741722`, 0.02222222222222222}, {0.22622516556291392`, 
          0.02222222222222222}, {0.22622516556291392`, 0}, {
          0.21675496688741722`, 0}}, {{0.22622516556291392`, 0}, {
          0.22622516556291392`, 0.02222222222222222}, {0.2471523178807947, 
          0.02222222222222222}, {0.2471523178807947, 0}, {
          0.22622516556291392`, 0}}, {{0.2471523178807947, 0}, {
          0.2471523178807947, 0.02222222222222222}, {0.2633112582781457, 
          0.02222222222222222}, {0.2633112582781457, 0}, {
          0.2471523178807947, 0}}, {{0.2633112582781457, 0}, {
          0.2633112582781457, 0.02222222222222222}, {0.2785430463576159, 
          0.02222222222222222}, {0.2785430463576159, 0}, {
          0.2633112582781457, 0}}, {{0.2785430463576159, 0}, {
          0.2785430463576159, 0.02222222222222222}, {0.3213245033112583, 
          0.02222222222222222}, {0.3213245033112583, 0}, {
          0.2785430463576159, 0}}, {{0.3213245033112583, 0}, {
          0.3213245033112583, 0.02222222222222222}, {0.34503311258278146`, 
          0.02222222222222222}, {0.34503311258278146`, 0}, {
          0.3213245033112583, 0}}, {{0.34503311258278146`, 0}, {
          0.34503311258278146`, 0.02222222222222222}, {0.36026490066225164`, 
          0.02222222222222222}, {0.36026490066225164`, 0}, {
          0.34503311258278146`, 0}}, {{0.36026490066225164`, 0}, {
          0.36026490066225164`, 0.02222222222222222}, {0.38019867549668873`, 
          0.02222222222222222}, {0.38019867549668873`, 0}, {
          0.36026490066225164`, 0}}, {{0.38019867549668873`, 0}, {
          0.38019867549668873`, 0.02222222222222222}, {0.39450331125827814`, 
          0.02222222222222222}, {0.39450331125827814`, 0}, {
          0.38019867549668873`, 0}}, {{0.39450331125827814`, 0}, {
          0.39450331125827814`, 0.02222222222222222}, {0.39927152317880793`, 
          0.02222222222222222}, {0.39927152317880793`, 0}, {
          0.39450331125827814`, 0}}, {{0.39927152317880793`, 0}, {
          0.39927152317880793`, 0.02222222222222222}, {0.4135099337748344, 
          0.02222222222222222}, {0.4135099337748344, 0}, {
          0.39927152317880793`, 0}}, {{0.4135099337748344, 0}, {
          0.4135099337748344, 0.02222222222222222}, {0.4277483443708609, 
          0.02222222222222222}, {0.4277483443708609, 0}, {
          0.4135099337748344, 0}}, {{0.4277483443708609, 0}, {
          0.4277483443708609, 0.02222222222222222}, {0.4410596026490066, 
          0.02222222222222222}, {0.4410596026490066, 0}, {
          0.4277483443708609, 0}}, {{0.4410596026490066, 0}, {
          0.4410596026490066, 0.02222222222222222}, {0.45437086092715234`, 
          0.02222222222222222}, {0.45437086092715234`, 0}, {
          0.4410596026490066, 0}}, {{0.45437086092715234`, 0}, {
          0.45437086092715234`, 0.02222222222222222}, {0.46675496688741724`, 
          0.02222222222222222}, {0.46675496688741724`, 0}, {
          0.45437086092715234`, 0}}, {{0.46675496688741724`, 0}, {
          0.46675496688741724`, 0.02222222222222222}, {0.4714569536423841, 
          0.02222222222222222}, {0.4714569536423841, 0}, {
          0.46675496688741724`, 0}}, {{0.4714569536423841, 0}, {
          0.4714569536423841, 0.02222222222222222}, {0.4746504782928624, 
          0.02222222222222222}, {0.4746504782928624, 0.02222222222222222}, {
          0.4765799024891616, 0.022053419477913422`}, {0.47845070210759205`, 
          0.021552140230954534`}, {0.4802060338484179, 
          0.020733615597604872`}, {0.48179256284493505`, 
          0.019622716034655308`}, {0.4831620832164066, 
          0.018253195663183768`}, {0.48427298277935615`, 
          0.016666666666666663`}, {0.4850915074127058, 
          0.014911334925840762`}, {0.4855927866596647, 
          0.013040535307410336`}, {0.4857615894039735, 0.01111111111111111}, {
          0.4857615894039735, 0.01111111111111111}, {0.4857615894039735, 
          0.01111111111111111}, {0.4857615894039735, 0.01111111111111111}, {
          0.4855927866596647, 0.009181686914811884}, {0.4850915074127058, 
          0.007310887296381458}, {0.48427298277935615`, 
          0.005555555555555556}, {0.4831620832164066, 0.003969026559038452}, {
          0.48179256284493505`, 0.0025995061875669113`}, {0.4802060338484179, 
          0.0014886066246173491`}, {0.47845070210759205`, 
          0.0006700819912676854}, {0.4765799024891616, 
          0.0001688027443087995}, {0.4746504782928624, 0.}, {
          0.4746504782928624, 0}, {0.4714569536423841, 0}}, {{
          0.5019205298013245, 0}, {0.49687270051508464`, 0}, {
          0.49687270051508464`, 0.}, {0.49494327631878543`, 
          0.0001688027443087995}, {0.493072476700355, 
          0.0006700819912676837}, {0.4913171449595291, 
          0.0014886066246173509`}, {0.489730615963012, 
          0.0025995061875669113`}, {0.48836109559154045`, 
          0.003969026559038452}, {0.4872501960285909, 0.005555555555555554}, {
          0.48643167139524124`, 0.007310887296381458}, {0.4859303921482823, 
          0.009181686914811887}, {0.4857615894039735, 
          0.011111111111111112`}, {0.4857615894039735, 0.01111111111111111}, {
          0.4857615894039735, 0.01111111111111111}, {0.4857615894039735, 
          0.011111111111111112`}, {0.4859303921482823, 
          0.013040535307410336`}, {0.48643167139524124`, 
          0.014911334925840763`}, {0.4872501960285909, 
          0.016666666666666663`}, {0.48836109559154045`, 
          0.01825319566318377}, {0.489730615963012, 0.019622716034655308`}, {
          0.4913171449595291, 0.020733615597604872`}, {0.493072476700355, 
          0.021552140230954538`}, {0.49494327631878543`, 
          0.022053419477913422`}, {0.49687270051508464`, 
          0.02222222222222222}, {0.49687270051508464`, 0.02222222222222222}, {
          0.5019205298013245, 0.02222222222222222}, {
          0.5019205298013245, 0}}, {{0.5019205298013245, 0}, {
          0.5019205298013245, 0.02222222222222222}, {0.5617880794701987, 
          0.02222222222222222}, {0.5617880794701987, 0}, {
          0.5019205298013245, 0}}, {{0.5617880794701987, 0}, {
          0.5617880794701987, 0.02222222222222222}, {0.5798675496688742, 
          0.02222222222222222}, {0.5798675496688742, 0}, {
          0.5617880794701987, 0}}, {{0.5798675496688742, 0}, {
          0.5798675496688742, 0.02222222222222222}, {0.5931788079470198, 
          0.02222222222222222}, {0.5931788079470198, 0}, {
          0.5798675496688742, 0}}, {{0.5931788079470198, 0}, {
          0.5931788079470198, 0.02222222222222222}, {0.6121854304635762, 
          0.02222222222222222}, {0.6121854304635762, 0}, {
          0.5931788079470198, 0}}, {{0.6121854304635762, 0}, {
          0.6121854304635762, 0.02222222222222222}, {0.6264238410596027, 
          0.02222222222222222}, {0.6264238410596027, 0}, {
          0.6121854304635762, 0}}, {{0.6264238410596027, 0}, {
          0.6264238410596027, 0.02222222222222222}, {0.6511258278145695, 
          0.02222222222222222}, {0.6511258278145695, 0}, {
          0.6264238410596027, 0}}, {{0.6511258278145695, 0}, {
          0.6511258278145695, 0.02222222222222222}, {0.665430463576159, 
          0.02222222222222222}, {0.665430463576159, 0}, {
          0.6511258278145695, 0}}, {{0.665430463576159, 0}, {
          0.665430463576159, 0.02222222222222222}, {0.685364238410596, 
          0.02222222222222222}, {0.685364238410596, 0}, {
          0.665430463576159, 0}}, {{0.685364238410596, 0}, {0.685364238410596,
           0.02222222222222222}, {0.6958278145695365, 0.02222222222222222}, {
          0.6958278145695365, 0}, {0.685364238410596, 0}}, {{
          0.6958278145695365, 0}, {0.6958278145695365, 0.02222222222222222}, {
          0.7072185430463576, 0.02222222222222222}, {0.7072185430463576, 0}, {
          0.6958278145695365, 0}}, {{0.7072185430463576, 0}, {
          0.7072185430463576, 0.02222222222222222}, {0.7214569536423842, 
          0.02222222222222222}, {0.7214569536423842, 0}, {
          0.7072185430463576, 0}}, {{0.7214569536423842, 0}, {
          0.7214569536423842, 0.02222222222222222}, {0.7290728476821192, 
          0.02222222222222222}, {0.7290728476821192, 0}, {
          0.7214569536423842, 0}}, {{0.7290728476821192, 0}, {
          0.7290728476821192, 0.02222222222222222}, {0.7414569536423841, 
          0.02222222222222222}, {0.7414569536423841, 0}, {
          0.7290728476821192, 0}}, {{0.7414569536423841, 0}, {
          0.7414569536423841, 0.02222222222222222}, {0.7680794701986755, 
          0.02222222222222222}, {0.7680794701986755, 0}, {
          0.7414569536423841, 0}}, {{0.7680794701986755, 0}, {
          0.7680794701986755, 0.02222222222222222}, {0.7832450331125828, 
          0.02222222222222222}, {0.7832450331125828, 0}, {
          0.7680794701986755, 0}}, {{0.7832450331125828, 0}, {
          0.7832450331125828, 0.02222222222222222}, {0.7908609271523179, 
          0.02222222222222222}, {0.7908609271523179, 0}, {
          0.7832450331125828, 0}}, {{0.7908609271523179, 0}, {
          0.7908609271523179, 0.02222222222222222}, {0.806092715231788, 
          0.02222222222222222}, {0.806092715231788, 0}, {
          0.7908609271523179, 0}}, {{0.806092715231788, 0}, {
          0.806092715231788, 0.02222222222222222}, {0.8355629139072848, 
          0.02222222222222222}, {0.8355629139072848, 0}, {
          0.806092715231788, 0}}, {{0.8355629139072848, 0}, {
          0.8355629139072848, 0.02222222222222222}, {0.8478807947019867, 
          0.02222222222222222}, {0.8478807947019867, 0}, {
          0.8355629139072848, 0}}, {{0.8478807947019867, 0}, {
          0.8478807947019867, 0.02222222222222222}, {0.863112582781457, 
          0.02222222222222222}, {0.863112582781457, 0}, {
          0.8478807947019867, 0}}, {{0.863112582781457, 0}, {
          0.863112582781457, 0.02222222222222222}, {0.8821192052980132, 
          0.02222222222222222}, {0.8821192052980132, 0}, {
          0.863112582781457, 0}}, {{0.8821192052980132, 0}, {
          0.8821192052980132, 0.02222222222222222}, {0.8878145695364238, 
          0.02222222222222222}, {0.8878145695364238, 0}, {
          0.8821192052980132, 0}}, {{0.8878145695364238, 0}, {
          0.8878145695364238, 0.02222222222222222}, {0.9011258278145695, 
          0.02222222222222222}, {0.9011258278145695, 0}, {
          0.8878145695364238, 0}}, {{0.9011258278145695, 0}, {
          0.9011258278145695, 0.02222222222222222}, {0.9249006622516557, 
          0.02222222222222222}, {0.9249006622516557, 0}, {
          0.9011258278145695, 0}}, {{0.9249006622516557, 0}, {
          0.9249006622516557, 0.02222222222222222}, {0.9372847682119205, 
          0.02222222222222222}, {0.9372847682119205, 0}, {
          0.9249006622516557, 0}}, {{0.9372847682119205, 0}, {
          0.9372847682119205, 0.02222222222222222}, {0.9534437086092715, 
          0.02222222222222222}, {0.9534437086092715, 0}, {
          0.9372847682119205, 0}}, {{0.9534437086092715, 0}, {
          0.9534437086092715, 0.02222222222222222}, {0.9772185430463576, 
          0.02222222222222222}, {0.9772185430463576, 0}, {
          0.9534437086092715, 0}}, {{0.9772185430463576, 0}, {
          0.9772185430463576, 0.02222222222222222}, {0.9944444444444445, 
          0.02222222222222222}, {0.9944444444444445, 0.02222222222222222}, {
          0.9954091565425941, 0.022137820850067817`}, {0.9963445563518093, 
          0.021887181226588375`}, {0.9972222222222222, 
          0.021477918909913546`}, {0.9980154867204808, 
          0.020922469128438762`}, {0.9987002469062166, 
          0.020237708942702992`}, {0.9992556966876913, 0.01944444444444444}, {
          0.9996649590043661, 0.018566778574031488`}, {0.9999155986278456, 
          0.017631378764816276`}, {1., 0.016666666666666663`}, {1., 
          0.016666666666666663`}, {1., 0.005555555555555555}, {1., 
          0.005555555555555555}, {0.9999155986278456, 0.004590843457405942}, {
          0.9996649590043661, 0.003655443648190729}, {0.9992556966876913, 
          0.002777777777777778}, {0.9987002469062166, 0.001984513279519226}, {
          0.9980154867204808, 0.0012997530937834557`}, {0.9972222222222222, 
          0.0007443033123086746}, {0.9963445563518093, 
          0.0003350409956338427}, {0.9954091565425941, 
          0.00008440137215439975}, {0.9944444444444445, 0.}, {
          0.9944444444444445, 0}, {0.9772185430463576, 0}}}, 
        VertexColors -> {{1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
          1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}, {0.75, 
          0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 
          0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 
          1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 
          1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 
          0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 
          0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {
          1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 
          1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0., 0., 0., 
          0., 0.}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 
          1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
          1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
          0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1.,
           1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
           0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
          0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25}, {0.25, 0.25, 0.25, 0.25, 
          0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
          0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
          0.25}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 
          0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
          1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 
          1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 
          0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 
          0.5}, {1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 
          1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 
          0.75, 0.75}, {1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 
          1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {
          0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 
          0.25, 0.25}, {1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
          1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}}], 
       EdgeForm[None], 
       RGBColor[1, 0, 0], 
       PolygonBox[{}]}, Frame -> {{False, False}, {True, False}}, 
      FrameTicks -> {{None, None}, {{{0., 
           FormBox["\"0 Mb\"", TraditionalForm]}, {0.12133481939366733`, 
           FormBox["\"30 Mb\"", TraditionalForm]}, {0.24266963878733466`, 
           FormBox["\"60 Mb\"", TraditionalForm]}, {0.364004458181002, 
           FormBox["\"90 Mb\"", TraditionalForm]}, {0.4853392775746693, 
           FormBox["\"120 Mb\"", TraditionalForm]}, {0.6066740969683367, 
           FormBox["\"150 Mb\"", TraditionalForm]}, {0.728008916362004, 
           FormBox["\"180 Mb\"", TraditionalForm]}, {0.8493437357556713, 
           FormBox["\"210 Mb\"", TraditionalForm]}, {0.9706785551493387, 
           FormBox["\"240 Mb\"", TraditionalForm]}}, None}}, 
      FrameStyle -> {{None, None}, {
         GrayLevel[0.5], None}}, ImageSize -> 450, AspectRatio -> Automatic, 
      ImagePadding -> {{10, Automatic}, {Automatic, Automatic}}],StyleBox[
     "\"chromosome 1\"", {
       GrayLevel[0.6], LinebreakAdjustments -> {1, 100, 1, 0, 100}, 
       LineIndent -> 0}, StripOnInput -> False]},
    "Labeled",
    DisplayFunction->(FormBox[
      GridBox[{{
         ItemBox[#2, Alignment -> {Left, Inherited}, DefaultBaseStyle -> 
          "LabeledLabel"]}, {
         TagBox[
          ItemBox[
           PaneBox[
            TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
            BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
          "SkipImageSizeLevel"]}}, 
       GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
       AutoDelete -> False, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
       BaselinePosition -> {2, 1}], TraditionalForm]& ),
    InterpretationFunction->(RowBox[{
       StyleBox[
       "Labeled", FontFamily -> "Bitstream Vera Sans", 
        FontSize -> -1 + Inherited], "[", 
       RowBox[{#, ",", #2, ",", 
         RowBox[{"(", "\[NoBreak]", 
           GridBox[{{
              StyleBox[
              "Top", FontFamily -> "Bitstream Vera Sans", 
               FontSize -> -1 + Inherited], 
              StyleBox[
              "Left", FontFamily -> "Bitstream Vera Sans", 
               FontSize -> -1 + Inherited]}}, RowSpacings -> 1, 
            ColumnSpacings -> 1, RowAlignments -> Baseline, ColumnAlignments -> 
            Center], "\[NoBreak]", ")"}]}], "]"}]& )],
   TraditionalForm], "Output",
  CellSize->{550, Automatic},
  ScriptLevel->0,
  FontFamily->"Times",
  FontSize->14,
  Background->None]], "Output",
 CellChangeTimes->{3.6775710193739185`*^9}]
}, Open  ]],

Cell[TextData[{
 "Die so aus dem ",
 StyleBox["WolframAlpha",
  FontSlant->"Italic"],
 "-Output extrahierte Visualisierung des Chromosoms ist in Abb. 2.29 gezeigt.\
\n\n",
 "Wir legen zudem die L\[ADoubleDot]nge des Chromosoms in einer Variablen ab \
und setzen eine Fenstergr\[ODoubleDot]\[SZ]e f\[UDoubleDot]r die Bestimmung \
der lokalen SNP-H\[ADoubleDot]ufigkeit fest:"
}], "Text",
 CellChangeTimes->{{3.6746239535985456`*^9, 3.674623967013565*^9}, {
  3.6746240001056137`*^9, 3.6746240007506146`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"len1", " ", "=", " ", 
   RowBox[{
    RowBox[{"WolframAlpha", "[", 
     RowBox[{"\"\<human chromosome 1\>\"", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}], 
         "}"}], ",", "\"\<NumberData\>\""}], "}"}]}], "]"}], "*", 
    "1000000"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613811683056653*^9, 3.613811693509246*^9}, {
  3.613831348578627*^9, 3.613831351544949*^9}, {3.6139635016340437`*^9, 
  3.61396351014581*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol1", " ", "=", " ", "500000"}], ";"}]], "Input",
 CellChangeTimes->{{3.613831521045134*^9, 3.613831529569553*^9}, 
   3.613963524859098*^9}],

Cell[TextData[{
 "Dann z\[ADoubleDot]hlen wir, wie viele SNPs in (nicht \
\[UDoubleDot]berlappenden) Fenstern der L\[ADoubleDot]nge ",
 StyleBox["sol1",
  FontWeight->"Bold"],
 " entlang des Chromosoms (in diesem Fall: Chromosom 1) auftreten und stellen \
das Resultat grafisch dar. In den ",
 StyleBox["Plot",
  FontWeight->"Bold"],
 "-Befehl gehen eine Reihe von Formatierungen ein. Wir normieren die Kurve \
auf Werte zwischen 0 und 0.2 und verschieben sie dann um 0.05 nach oben, \
damit sie sich besser in die Grafik aus ",
 StyleBox["WolframAlpha",
  FontSlant->"Italic"],
 " einf\[UDoubleDot]gen l\[ADoubleDot]sst. Zugleich kopieren wir die \
Achsenbeschriftung aus der Abbildung \[UDoubleDot]ber ",
 StyleBox["FrameTicks",
  FontWeight->"Bold"],
 " hinein."
}], "Text",
 CellChangeTimes->{{3.6746240521466904`*^9, 3.674624075387724*^9}, 
   3.6746241107137766`*^9, 3.677491812897143*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"gwas1b", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"k1", "/", "len1"}], "]"}], ",", 
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Cases", "[", 
           RowBox[{"gwas1", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"n1_", ",", "n2_", ",", "n3__"}], "}"}], " ", "/;", " ", 
             RowBox[{"n2", "\[Equal]", "\"\<chr1\>\""}]}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
         RowBox[{"nn1_Integer", " ", "/;", " ", 
          RowBox[{"k1", "\[LessEqual]", " ", "nn1", "\[LessEqual]", " ", 
           RowBox[{"k1", "+", "sol1"}]}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"k1", ",", "0", ",", "len1", ",", "sol1"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.61380973644063*^9, 3.6138098244648247`*^9}, 
   3.613809859235758*^9, {3.613809891348921*^9, 3.613809912644627*^9}, {
   3.613810238752625*^9, 3.613810257230132*^9}, {3.6138116761542873`*^9, 
   3.6138117026698523`*^9}, {3.613831274825848*^9, 3.6138312749041243`*^9}, {
   3.613831390898347*^9, 3.613831414208199*^9}, {3.613831536775001*^9, 
   3.613831539798684*^9}, {3.613963543628002*^9, 3.613963563312174*^9}, {
   3.613963604714489*^9, 3.613963606747452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1b", " ", "=", " ", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"gwas1b", " ", "/.", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"n1", ",", 
        RowBox[{
         RowBox[{"0.2", " ", 
          RowBox[{"n2", "/", 
           RowBox[{"Max", "[", 
            RowBox[{"Flatten", "[", "gwas1b", "]"}], "]"}]}]}], "+", 
         "0.05"}]}], "}"}]}]}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "0.2"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.01"}], ",", "0.2"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
    ",", 
    RowBox[{"FrameTicks", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"None", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"temp1", "[", 
            RowBox[{"[", 
             RowBox[{
             "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", "2", 
              ",", "2", ",", "1"}], "]"}], "]"}], " ", "/.", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n1_Real", ",", " ", 
              RowBox[{"FormBox", "[", 
               RowBox[{"n2_String", ",", "n3__"}], "]"}]}], "}"}], 
            "\[RuleDelayed]", " ", 
            RowBox[{"{", 
             RowBox[{"n1", ",", 
              RowBox[{"StringDrop", "[", 
               RowBox[{
                RowBox[{"StringDrop", "[", 
                 RowBox[{"n2", ",", "1"}], "]"}], ",", 
                RowBox[{"-", "1"}]}], "]"}]}], "}"}]}]}], ")"}], ",", 
         "None"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613809863744998*^9, 3.613809868489357*^9}, {
   3.613809928118967*^9, 3.613809962373225*^9}, 3.613811510501977*^9, {
   3.6138117201182327`*^9, 3.613811720700678*^9}, {3.613811758119294*^9, 
   3.613811785682914*^9}, {3.613811820075597*^9, 3.613811823777542*^9}, {
   3.613830708744878*^9, 3.613830846019968*^9}, {3.613830882131878*^9, 
   3.6138309102301598`*^9}, {3.61383095016476*^9, 3.613831028889518*^9}, {
   3.613831437705434*^9, 3.613831455496807*^9}, {3.614044977704077*^9, 
   3.614044984643592*^9}, {3.6140452493751297`*^9, 3.614045263298336*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdVQ1M1HUYPm/FAIdokDlKyOXMWxoUaUGePxEdDtTJKW26y1KJsEbArGCx
7Po4hw1BEVMPRoAHeQccx8nB8XUcx8fBHfdBjqAPUpmo7aIsGIvoC3qv57f+
t91uz97v932e3605mil7TSwSifIXvou//31Ulxc/Grb72EZz6Fuvsv/jLFZY
fvNeQKGOTYfuWB1RnSuwK9hP+8aXjUzp2eMdpqnLpz9hF2SJkuoSg88/H/H9
Ge7daksBsw6HPCbtbvTFn4W9OXg6ZTSvmMWV+jUd31bry1fC7pWdcMXcrWOn
008q5Rc/E/RzCXZ5d4DxlkGFeKpXBhwZduF2mqsc/lS/gsnHbMr35Sb2Yczy
wNm3K2Gnfqown3dypNL00RXMT/2p0c+B4tKYvLPVLP26YnNQ+jVfvzWwm7ce
GZaWf8GCR6YWMhp9/V9Ff+u9646L6jTANI8W9c5d/FHU01oLTPPVAc/HGy4p
bfXANK8O86Tez4naNdIgmF/PHvXULMkI07PXXeGpyl/0sNM+GnGvMvUSfdpv
HNN+DPD3vHd7PuFvA+alfV2D/4PJtgSJXxPmp/1xHPuk9nxgkBH90z45zvyz
4IY3pJlNpKw9vHPC6NtvM9N+W9m2WtvO1Nczn3KGtbCog38VT0a2+vbdgvgx
jSxHt8aEfmn/HAcpNvUUrW9F/3SPVvB5+0urgrMj23Bfuk8b8udsmD8k29yO
eele7chXK/6+JlraIeAnxzfHLL+G7ugU3JPjhxuubJ1NNAvuawY/E5WnPh1N
7kI9uncX8nfVP/emfIMFmO5vQb5vVq1b4WzgmPjA8czHj7RIo7sF/OjGfpb9
7P+yrpnbiS/dqCc59Ls4ItYq0JcV+eP7vFeLOq0CPlkRfzhqfK8orgeY+NUD
/uaWumayenswP/GtF/7FfhbVrYRegX57ca/67MZtMge3Ex/7EG/7ruqOdW8f
6hE/uX0ioaQg+ss+AV/7gf8wKJ9Vp/QL3rN+3G9leM5Y6Nfcn/hsA37m3wAb
6hG/uT1p5uDa2Rs2Ad8HsI+0V5LsaccGEE/8H0B9hX1L1uidAcSTHgaBVZue
XrnrDY5JHxwbKyIWNjqI+UgvdtjdS1cclWTbBe81t//wrthfNWMX6MkB/MDE
dH1grkOgLwf6D98zuT9v3oH5SG9D8I8xfTXnPTmE94b0N4T4/U8MfC4XO3Ff
0qMT+8sobN3pVDrRP+mT4/w5rVca4EJ90qsL8VWpZed0BRyTfrl/p/vM8xHL
3cCkZzf6G439YLzovBvvG+nbjfdwTmaKUyz1wJ/07mHJi3BfJzvl31jywh6P
4P3nOMSsuXu/0IP69B54sP+KE1WxGo9H8H/hYVsOtMS/82IT2ygpPXPkoWHk
o/eCY1399o6ypGFfvkH2D7IxTfA=
      "]], LineBox[CompressedData["
1:eJxdV3k4lGsbx9eCPkllqZR8llLSIqXQq3AUaZEW0kI+0SYpfBUp0YYKHUeU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      "]]}}, {}},
  AspectRatio->0.2,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {True, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{None, None}, {{{0., 
       FormBox["\"0 Mb\"", TraditionalForm]}, {0.12133481939366733`, 
       FormBox["\"30 Mb\"", TraditionalForm]}, {0.24266963878733466`, 
       FormBox["\"60 Mb\"", TraditionalForm]}, {0.364004458181002, 
       FormBox["\"90 Mb\"", TraditionalForm]}, {0.4853392775746693, 
       FormBox["\"120 Mb\"", TraditionalForm]}, {0.6066740969683367, 
       FormBox["\"150 Mb\"", TraditionalForm]}, {0.728008916362004, 
       FormBox["\"180 Mb\"", TraditionalForm]}, {0.8493437357556713, 
       FormBox["\"210 Mb\"", TraditionalForm]}, {0.9706785551493387, 
       FormBox["\"240 Mb\"", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {-0.01, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677571031058339*^9}]
}, Open  ]],

Cell["\<\
Diese Abfolge von Befehlen ergibt die in Abb. 2.30 angegebene Grafik.

Im letzten Schritt legen wir das Bild des Chromosoms noch zwischen Kurvenzug \
und Achse.\
\>", "Text",
 CellChangeTimes->{{3.674624147610831*^9, 3.6746241783948793`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1b", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"temp1", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "]"}], 
     "]"}], "]"}], ",", "p1b", ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613830864717946*^9, 3.6138308662376842`*^9}, {
  3.6138309219717207`*^9, 3.613830931011495*^9}, {3.6138314840934134`*^9, 
  3.613831487436974*^9}, {3.614045275135894*^9, 3.61404527939147*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdVQ1M1HUYPm/FAIdokDlKyOXMWxoUaUGePxEdDtTJKW26y1KJsEbArGCx
7Po4hw1BEVMPRoAHeQccx8nB8XUcx8fBHfdBjqAPUpmo7aIsGIvoC3qv57f+
t91uz97v932e3605mil7TSwSifIXvou//31Ulxc/Grb72EZz6Fuvsv/jLFZY
fvNeQKGOTYfuWB1RnSuwK9hP+8aXjUzp2eMdpqnLpz9hF2SJkuoSg88/H/H9
Ge7daksBsw6HPCbtbvTFn4W9OXg6ZTSvmMWV+jUd31bry1fC7pWdcMXcrWOn
008q5Rc/E/RzCXZ5d4DxlkGFeKpXBhwZduF2mqsc/lS/gsnHbMr35Sb2Yczy
wNm3K2Gnfqown3dypNL00RXMT/2p0c+B4tKYvLPVLP26YnNQ+jVfvzWwm7ce
GZaWf8GCR6YWMhp9/V9Ff+u9646L6jTANI8W9c5d/FHU01oLTPPVAc/HGy4p
bfXANK8O86Tez4naNdIgmF/PHvXULMkI07PXXeGpyl/0sNM+GnGvMvUSfdpv
HNN+DPD3vHd7PuFvA+alfV2D/4PJtgSJXxPmp/1xHPuk9nxgkBH90z45zvyz
4IY3pJlNpKw9vHPC6NtvM9N+W9m2WtvO1Nczn3KGtbCog38VT0a2+vbdgvgx
jSxHt8aEfmn/HAcpNvUUrW9F/3SPVvB5+0urgrMj23Bfuk8b8udsmD8k29yO
eele7chXK/6+JlraIeAnxzfHLL+G7ugU3JPjhxuubJ1NNAvuawY/E5WnPh1N
7kI9uncX8nfVP/emfIMFmO5vQb5vVq1b4WzgmPjA8czHj7RIo7sF/OjGfpb9
7P+yrpnbiS/dqCc59Ls4ItYq0JcV+eP7vFeLOq0CPlkRfzhqfK8orgeY+NUD
/uaWumayenswP/GtF/7FfhbVrYRegX57ca/67MZtMge3Ex/7EG/7ruqOdW8f
6hE/uX0ioaQg+ss+AV/7gf8wKJ9Vp/QL3rN+3G9leM5Y6Nfcn/hsA37m3wAb
6hG/uT1p5uDa2Rs2Ad8HsI+0V5LsaccGEE/8H0B9hX1L1uidAcSTHgaBVZue
XrnrDY5JHxwbKyIWNjqI+UgvdtjdS1cclWTbBe81t//wrthfNWMX6MkB/MDE
dH1grkOgLwf6D98zuT9v3oH5SG9D8I8xfTXnPTmE94b0N4T4/U8MfC4XO3Ff
0qMT+8sobN3pVDrRP+mT4/w5rVca4EJ90qsL8VWpZed0BRyTfrl/p/vM8xHL
3cCkZzf6G439YLzovBvvG+nbjfdwTmaKUyz1wJ/07mHJi3BfJzvl31jywh6P
4P3nOMSsuXu/0IP69B54sP+KE1WxGo9H8H/hYVsOtMS/82IT2ygpPXPkoWHk
o/eCY1399o6ypGFfvkH2D7IxTfA=
       "]], LineBox[CompressedData["
1:eJxdV3k4lGsbx9eCPkllqZR8llLSIqXQq3AUaZEW0kI+0SYpfBUp0YYKHUeU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       "]]}}, {}}, 
   {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.0015]}], 
    PolygonBox[{{{0.006622516556291391, 0}, {0.005555555555555555, 0}, {
       0.005555555555555554, 0.}, {0.004590843457405942, 
       0.00008440137215439975}, {0.00365544364819073, 
       0.00033504099563384186`}, {0.002777777777777775, 
       0.0007443033123086754}, {0.001984513279519225, 
       0.0012997530937834557`}, {0.0012997530937834557`, 
       0.001984513279519226}, {0.0007443033123086746, 0.002777777777777777}, {
       0.00033504099563384186`, 0.003655443648190729}, {
       0.00008440137215439888, 0.004590843457405944}, {0., 
       0.005555555555555556}, {0., 0.005555555555555555}, {0., 
       0.016666666666666663`}, {0., 0.016666666666666663`}, {
       0.00008440137215439975, 0.017631378764816276`}, {0.0003350409956338427,
        0.018566778574031488`}, {0.0007443033123086737, 
       0.01944444444444444}, {0.0012997530937834557`, 
       0.020237708942702992`}, {0.0019845132795192257`, 
       0.020922469128438762`}, {0.002777777777777776, 
       0.021477918909913542`}, {0.003655443648190729, 
       0.021887181226588375`}, {0.004590843457405942, 
       0.022137820850067817`}, {0.005555555555555555, 0.02222222222222222}, {
       0.005555555555555555, 0.02222222222222222}, {0.006622516556291391, 
       0.02222222222222222}, {0.006622516556291391, 0}}, {{
       0.006622516556291391, 0}, {0.006622516556291391, 
       0.02222222222222222}, {0.016158940397350992`, 0.02222222222222222}, {
       0.016158940397350992`, 0}, {0.006622516556291391, 0}}, {{
       0.016158940397350992`, 0}, {0.016158940397350992`, 
       0.02222222222222222}, {0.022781456953642386`, 0.02222222222222222}, {
       0.022781456953642386`, 0}, {0.016158940397350992`, 0}}, {{
       0.022781456953642386`, 0}, {0.022781456953642386`, 
       0.02222222222222222}, {0.030397350993377485`, 0.02222222222222222}, {
       0.030397350993377485`, 0}, {0.022781456953642386`, 0}}, {{
       0.030397350993377485`, 0}, {0.030397350993377485`, 
       0.02222222222222222}, {0.04370860927152318, 0.02222222222222222}, {
       0.04370860927152318, 0}, {0.030397350993377485`, 0}}, {{
       0.04370860927152318, 0}, {0.04370860927152318, 0.02222222222222222}, {
       0.057019867549668875`, 0.02222222222222222}, {
       0.057019867549668875`, 0}, {0.04370860927152318, 0}}, {{
       0.057019867549668875`, 0}, {0.057019867549668875`, 
       0.02222222222222222}, {0.07986754966887417, 0.02222222222222222}, {
       0.07986754966887417, 0}, {0.057019867549668875`, 0}}, {{
       0.07986754966887417, 0}, {0.07986754966887417, 0.02222222222222222}, {
       0.08748344370860928, 0.02222222222222222}, {0.08748344370860928, 0}, {
       0.07986754966887417, 0}}, {{0.08748344370860928, 0}, {
       0.08748344370860928, 0.02222222222222222}, {0.10072847682119206`, 
       0.02222222222222222}, {0.10072847682119206`, 0}, {
       0.08748344370860928, 0}}, {{0.10072847682119206`, 0}, {
       0.10072847682119206`, 0.02222222222222222}, {0.10933774834437086`, 
       0.02222222222222222}, {0.10933774834437086`, 0}, {
       0.10072847682119206`, 0}}, {{0.10933774834437086`, 0}, {
       0.10933774834437086`, 0.02222222222222222}, {0.11788079470198676`, 
       0.02222222222222222}, {0.11788079470198676`, 0}, {
       0.10933774834437086`, 0}}, {{0.11788079470198676`, 0}, {
       0.11788079470198676`, 0.02222222222222222}, {0.12549668874172185`, 
       0.02222222222222222}, {0.12549668874172185`, 0}, {
       0.11788079470198676`, 0}}, {{0.12549668874172185`, 0}, {
       0.12549668874172185`, 0.02222222222222222}, {0.14635761589403973`, 
       0.02222222222222222}, {0.14635761589403973`, 0}, {
       0.12549668874172185`, 0}}, {{0.14635761589403973`, 0}, {
       0.14635761589403973`, 0.02222222222222222}, {0.15966887417218542`, 
       0.02222222222222222}, {0.15966887417218542`, 0}, {
       0.14635761589403973`, 0}}, {{0.15966887417218542`, 0}, {
       0.15966887417218542`, 0.02222222222222222}, {0.18344370860927153`, 
       0.02222222222222222}, {0.18344370860927153`, 0}, {
       0.15966887417218542`, 0}}, {{0.18344370860927153`, 0}, {
       0.18344370860927153`, 0.02222222222222222}, {0.19774834437086092`, 
       0.02222222222222222}, {0.19774834437086092`, 0}, {
       0.18344370860927153`, 0}}, {{0.19774834437086092`, 0}, {
       0.19774834437086092`, 0.02222222222222222}, {0.21675496688741722`, 
       0.02222222222222222}, {0.21675496688741722`, 0}, {
       0.19774834437086092`, 0}}, {{0.21675496688741722`, 0}, {
       0.21675496688741722`, 0.02222222222222222}, {0.22622516556291392`, 
       0.02222222222222222}, {0.22622516556291392`, 0}, {
       0.21675496688741722`, 0}}, {{0.22622516556291392`, 0}, {
       0.22622516556291392`, 0.02222222222222222}, {0.2471523178807947, 
       0.02222222222222222}, {0.2471523178807947, 0}, {
       0.22622516556291392`, 0}}, {{0.2471523178807947, 0}, {
       0.2471523178807947, 0.02222222222222222}, {0.2633112582781457, 
       0.02222222222222222}, {0.2633112582781457, 0}, {
       0.2471523178807947, 0}}, {{0.2633112582781457, 0}, {0.2633112582781457,
        0.02222222222222222}, {0.2785430463576159, 0.02222222222222222}, {
       0.2785430463576159, 0}, {0.2633112582781457, 0}}, {{
       0.2785430463576159, 0}, {0.2785430463576159, 0.02222222222222222}, {
       0.3213245033112583, 0.02222222222222222}, {0.3213245033112583, 0}, {
       0.2785430463576159, 0}}, {{0.3213245033112583, 0}, {0.3213245033112583,
        0.02222222222222222}, {0.34503311258278146`, 0.02222222222222222}, {
       0.34503311258278146`, 0}, {0.3213245033112583, 0}}, {{
       0.34503311258278146`, 0}, {0.34503311258278146`, 
       0.02222222222222222}, {0.36026490066225164`, 0.02222222222222222}, {
       0.36026490066225164`, 0}, {0.34503311258278146`, 0}}, {{
       0.36026490066225164`, 0}, {0.36026490066225164`, 
       0.02222222222222222}, {0.38019867549668873`, 0.02222222222222222}, {
       0.38019867549668873`, 0}, {0.36026490066225164`, 0}}, {{
       0.38019867549668873`, 0}, {0.38019867549668873`, 
       0.02222222222222222}, {0.39450331125827814`, 0.02222222222222222}, {
       0.39450331125827814`, 0}, {0.38019867549668873`, 0}}, {{
       0.39450331125827814`, 0}, {0.39450331125827814`, 
       0.02222222222222222}, {0.39927152317880793`, 0.02222222222222222}, {
       0.39927152317880793`, 0}, {0.39450331125827814`, 0}}, {{
       0.39927152317880793`, 0}, {0.39927152317880793`, 
       0.02222222222222222}, {0.4135099337748344, 0.02222222222222222}, {
       0.4135099337748344, 0}, {0.39927152317880793`, 0}}, {{
       0.4135099337748344, 0}, {0.4135099337748344, 0.02222222222222222}, {
       0.4277483443708609, 0.02222222222222222}, {0.4277483443708609, 0}, {
       0.4135099337748344, 0}}, {{0.4277483443708609, 0}, {0.4277483443708609,
        0.02222222222222222}, {0.4410596026490066, 0.02222222222222222}, {
       0.4410596026490066, 0}, {0.4277483443708609, 0}}, {{
       0.4410596026490066, 0}, {0.4410596026490066, 0.02222222222222222}, {
       0.45437086092715234`, 0.02222222222222222}, {
       0.45437086092715234`, 0}, {0.4410596026490066, 0}}, {{
       0.45437086092715234`, 0}, {0.45437086092715234`, 
       0.02222222222222222}, {0.46675496688741724`, 0.02222222222222222}, {
       0.46675496688741724`, 0}, {0.45437086092715234`, 0}}, {{
       0.46675496688741724`, 0}, {0.46675496688741724`, 
       0.02222222222222222}, {0.4714569536423841, 0.02222222222222222}, {
       0.4714569536423841, 0}, {0.46675496688741724`, 0}}, {{
       0.4714569536423841, 0}, {0.4714569536423841, 0.02222222222222222}, {
       0.4746504782928624, 0.02222222222222222}, {0.4746504782928624, 
       0.02222222222222222}, {0.4765799024891616, 0.022053419477913422`}, {
       0.47845070210759205`, 0.021552140230954534`}, {0.4802060338484179, 
       0.020733615597604872`}, {0.48179256284493505`, 
       0.019622716034655308`}, {0.4831620832164066, 0.018253195663183768`}, {
       0.48427298277935615`, 0.016666666666666663`}, {0.4850915074127058, 
       0.014911334925840762`}, {0.4855927866596647, 0.013040535307410336`}, {
       0.4857615894039735, 0.01111111111111111}, {0.4857615894039735, 
       0.01111111111111111}, {0.4857615894039735, 0.01111111111111111}, {
       0.4857615894039735, 0.01111111111111111}, {0.4855927866596647, 
       0.009181686914811884}, {0.4850915074127058, 0.007310887296381458}, {
       0.48427298277935615`, 0.005555555555555556}, {0.4831620832164066, 
       0.003969026559038452}, {0.48179256284493505`, 
       0.0025995061875669113`}, {0.4802060338484179, 
       0.0014886066246173491`}, {0.47845070210759205`, 
       0.0006700819912676854}, {0.4765799024891616, 0.0001688027443087995}, {
       0.4746504782928624, 0.}, {0.4746504782928624, 0}, {
       0.4714569536423841, 0}}, {{0.5019205298013245, 0}, {
       0.49687270051508464`, 0}, {0.49687270051508464`, 0.}, {
       0.49494327631878543`, 0.0001688027443087995}, {0.493072476700355, 
       0.0006700819912676837}, {0.4913171449595291, 0.0014886066246173509`}, {
       0.489730615963012, 0.0025995061875669113`}, {0.48836109559154045`, 
       0.003969026559038452}, {0.4872501960285909, 0.005555555555555554}, {
       0.48643167139524124`, 0.007310887296381458}, {0.4859303921482823, 
       0.009181686914811887}, {0.4857615894039735, 0.011111111111111112`}, {
       0.4857615894039735, 0.01111111111111111}, {0.4857615894039735, 
       0.01111111111111111}, {0.4857615894039735, 0.011111111111111112`}, {
       0.4859303921482823, 0.013040535307410336`}, {0.48643167139524124`, 
       0.014911334925840763`}, {0.4872501960285909, 0.016666666666666663`}, {
       0.48836109559154045`, 0.01825319566318377}, {0.489730615963012, 
       0.019622716034655308`}, {0.4913171449595291, 0.020733615597604872`}, {
       0.493072476700355, 0.021552140230954538`}, {0.49494327631878543`, 
       0.022053419477913422`}, {0.49687270051508464`, 0.02222222222222222}, {
       0.49687270051508464`, 0.02222222222222222}, {0.5019205298013245, 
       0.02222222222222222}, {0.5019205298013245, 0}}, {{
       0.5019205298013245, 0}, {0.5019205298013245, 0.02222222222222222}, {
       0.5617880794701987, 0.02222222222222222}, {0.5617880794701987, 0}, {
       0.5019205298013245, 0}}, {{0.5617880794701987, 0}, {0.5617880794701987,
        0.02222222222222222}, {0.5798675496688742, 0.02222222222222222}, {
       0.5798675496688742, 0}, {0.5617880794701987, 0}}, {{
       0.5798675496688742, 0}, {0.5798675496688742, 0.02222222222222222}, {
       0.5931788079470198, 0.02222222222222222}, {0.5931788079470198, 0}, {
       0.5798675496688742, 0}}, {{0.5931788079470198, 0}, {0.5931788079470198,
        0.02222222222222222}, {0.6121854304635762, 0.02222222222222222}, {
       0.6121854304635762, 0}, {0.5931788079470198, 0}}, {{
       0.6121854304635762, 0}, {0.6121854304635762, 0.02222222222222222}, {
       0.6264238410596027, 0.02222222222222222}, {0.6264238410596027, 0}, {
       0.6121854304635762, 0}}, {{0.6264238410596027, 0}, {0.6264238410596027,
        0.02222222222222222}, {0.6511258278145695, 0.02222222222222222}, {
       0.6511258278145695, 0}, {0.6264238410596027, 0}}, {{
       0.6511258278145695, 0}, {0.6511258278145695, 0.02222222222222222}, {
       0.665430463576159, 0.02222222222222222}, {0.665430463576159, 0}, {
       0.6511258278145695, 0}}, {{0.665430463576159, 0}, {0.665430463576159, 
       0.02222222222222222}, {0.685364238410596, 0.02222222222222222}, {
       0.685364238410596, 0}, {0.665430463576159, 0}}, {{
       0.685364238410596, 0}, {0.685364238410596, 0.02222222222222222}, {
       0.6958278145695365, 0.02222222222222222}, {0.6958278145695365, 0}, {
       0.685364238410596, 0}}, {{0.6958278145695365, 0}, {0.6958278145695365, 
       0.02222222222222222}, {0.7072185430463576, 0.02222222222222222}, {
       0.7072185430463576, 0}, {0.6958278145695365, 0}}, {{
       0.7072185430463576, 0}, {0.7072185430463576, 0.02222222222222222}, {
       0.7214569536423842, 0.02222222222222222}, {0.7214569536423842, 0}, {
       0.7072185430463576, 0}}, {{0.7214569536423842, 0}, {0.7214569536423842,
        0.02222222222222222}, {0.7290728476821192, 0.02222222222222222}, {
       0.7290728476821192, 0}, {0.7214569536423842, 0}}, {{
       0.7290728476821192, 0}, {0.7290728476821192, 0.02222222222222222}, {
       0.7414569536423841, 0.02222222222222222}, {0.7414569536423841, 0}, {
       0.7290728476821192, 0}}, {{0.7414569536423841, 0}, {0.7414569536423841,
        0.02222222222222222}, {0.7680794701986755, 0.02222222222222222}, {
       0.7680794701986755, 0}, {0.7414569536423841, 0}}, {{
       0.7680794701986755, 0}, {0.7680794701986755, 0.02222222222222222}, {
       0.7832450331125828, 0.02222222222222222}, {0.7832450331125828, 0}, {
       0.7680794701986755, 0}}, {{0.7832450331125828, 0}, {0.7832450331125828,
        0.02222222222222222}, {0.7908609271523179, 0.02222222222222222}, {
       0.7908609271523179, 0}, {0.7832450331125828, 0}}, {{
       0.7908609271523179, 0}, {0.7908609271523179, 0.02222222222222222}, {
       0.806092715231788, 0.02222222222222222}, {0.806092715231788, 0}, {
       0.7908609271523179, 0}}, {{0.806092715231788, 0}, {0.806092715231788, 
       0.02222222222222222}, {0.8355629139072848, 0.02222222222222222}, {
       0.8355629139072848, 0}, {0.806092715231788, 0}}, {{
       0.8355629139072848, 0}, {0.8355629139072848, 0.02222222222222222}, {
       0.8478807947019867, 0.02222222222222222}, {0.8478807947019867, 0}, {
       0.8355629139072848, 0}}, {{0.8478807947019867, 0}, {0.8478807947019867,
        0.02222222222222222}, {0.863112582781457, 0.02222222222222222}, {
       0.863112582781457, 0}, {0.8478807947019867, 0}}, {{
       0.863112582781457, 0}, {0.863112582781457, 0.02222222222222222}, {
       0.8821192052980132, 0.02222222222222222}, {0.8821192052980132, 0}, {
       0.863112582781457, 0}}, {{0.8821192052980132, 0}, {0.8821192052980132, 
       0.02222222222222222}, {0.8878145695364238, 0.02222222222222222}, {
       0.8878145695364238, 0}, {0.8821192052980132, 0}}, {{
       0.8878145695364238, 0}, {0.8878145695364238, 0.02222222222222222}, {
       0.9011258278145695, 0.02222222222222222}, {0.9011258278145695, 0}, {
       0.8878145695364238, 0}}, {{0.9011258278145695, 0}, {0.9011258278145695,
        0.02222222222222222}, {0.9249006622516557, 0.02222222222222222}, {
       0.9249006622516557, 0}, {0.9011258278145695, 0}}, {{
       0.9249006622516557, 0}, {0.9249006622516557, 0.02222222222222222}, {
       0.9372847682119205, 0.02222222222222222}, {0.9372847682119205, 0}, {
       0.9249006622516557, 0}}, {{0.9372847682119205, 0}, {0.9372847682119205,
        0.02222222222222222}, {0.9534437086092715, 0.02222222222222222}, {
       0.9534437086092715, 0}, {0.9372847682119205, 0}}, {{
       0.9534437086092715, 0}, {0.9534437086092715, 0.02222222222222222}, {
       0.9772185430463576, 0.02222222222222222}, {0.9772185430463576, 0}, {
       0.9534437086092715, 0}}, {{0.9772185430463576, 0}, {0.9772185430463576,
        0.02222222222222222}, {0.9944444444444445, 0.02222222222222222}, {
       0.9944444444444445, 0.02222222222222222}, {0.9954091565425941, 
       0.022137820850067817`}, {0.9963445563518093, 0.021887181226588375`}, {
       0.9972222222222222, 0.021477918909913546`}, {0.9980154867204808, 
       0.020922469128438762`}, {0.9987002469062166, 0.020237708942702992`}, {
       0.9992556966876913, 0.01944444444444444}, {0.9996649590043661, 
       0.018566778574031488`}, {0.9999155986278456, 0.017631378764816276`}, {
       1., 0.016666666666666663`}, {1., 0.016666666666666663`}, {1., 
       0.005555555555555555}, {1., 0.005555555555555555}, {0.9999155986278456,
        0.004590843457405942}, {0.9996649590043661, 0.003655443648190729}, {
       0.9992556966876913, 0.002777777777777778}, {0.9987002469062166, 
       0.001984513279519226}, {0.9980154867204808, 0.0012997530937834557`}, {
       0.9972222222222222, 0.0007443033123086746}, {0.9963445563518093, 
       0.0003350409956338427}, {0.9954091565425941, 0.00008440137215439975}, {
       0.9944444444444445, 0.}, {0.9944444444444445, 0}, {
       0.9772185430463576, 0}}},
     VertexColors->{{1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
       1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75,
        0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {
       1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {
       0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75,
        0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {
       1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 
       1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 
       0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 
       1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.25, 
       0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25,
        0.25}, {1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 
       1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
       0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25}, {0.25, 0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 
       0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
       1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {
       0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 
       0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 
       1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0., 0., 0., 
       0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1.,
        1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 
       0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
       1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
       1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
        1., 1., 1., 1., 1.}}], 
    {RGBColor[1, 0, 0], EdgeForm[None], PolygonBox[{}]}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdVQ1M1HUYPm/FAIdokDlKyOXMWxoUaUGePxEdDtTJKW26y1KJsEbArGCx
7Po4hw1BEVMPRoAHeQccx8nB8XUcx8fBHfdBjqAPUpmo7aIsGIvoC3qv57f+
t91uz97v932e3605mil7TSwSifIXvou//31Ulxc/Grb72EZz6Fuvsv/jLFZY
fvNeQKGOTYfuWB1RnSuwK9hP+8aXjUzp2eMdpqnLpz9hF2SJkuoSg88/H/H9
Ge7daksBsw6HPCbtbvTFn4W9OXg6ZTSvmMWV+jUd31bry1fC7pWdcMXcrWOn
008q5Rc/E/RzCXZ5d4DxlkGFeKpXBhwZduF2mqsc/lS/gsnHbMr35Sb2Yczy
wNm3K2Gnfqown3dypNL00RXMT/2p0c+B4tKYvLPVLP26YnNQ+jVfvzWwm7ce
GZaWf8GCR6YWMhp9/V9Ff+u9646L6jTANI8W9c5d/FHU01oLTPPVAc/HGy4p
bfXANK8O86Tez4naNdIgmF/PHvXULMkI07PXXeGpyl/0sNM+GnGvMvUSfdpv
HNN+DPD3vHd7PuFvA+alfV2D/4PJtgSJXxPmp/1xHPuk9nxgkBH90z45zvyz
4IY3pJlNpKw9vHPC6NtvM9N+W9m2WtvO1Nczn3KGtbCog38VT0a2+vbdgvgx
jSxHt8aEfmn/HAcpNvUUrW9F/3SPVvB5+0urgrMj23Bfuk8b8udsmD8k29yO
eele7chXK/6+JlraIeAnxzfHLL+G7ugU3JPjhxuubJ1NNAvuawY/E5WnPh1N
7kI9uncX8nfVP/emfIMFmO5vQb5vVq1b4WzgmPjA8czHj7RIo7sF/OjGfpb9
7P+yrpnbiS/dqCc59Ls4ItYq0JcV+eP7vFeLOq0CPlkRfzhqfK8orgeY+NUD
/uaWumayenswP/GtF/7FfhbVrYRegX57ca/67MZtMge3Ex/7EG/7ruqOdW8f
6hE/uX0ioaQg+ss+AV/7gf8wKJ9Vp/QL3rN+3G9leM5Y6Nfcn/hsA37m3wAb
6hG/uT1p5uDa2Rs2Ad8HsI+0V5LsaccGEE/8H0B9hX1L1uidAcSTHgaBVZue
XrnrDY5JHxwbKyIWNjqI+UgvdtjdS1cclWTbBe81t//wrthfNWMX6MkB/MDE
dH1grkOgLwf6D98zuT9v3oH5SG9D8I8xfTXnPTmE94b0N4T4/U8MfC4XO3Ff
0qMT+8sobN3pVDrRP+mT4/w5rVca4EJ90qsL8VWpZed0BRyTfrl/p/vM8xHL
3cCkZzf6G439YLzovBvvG+nbjfdwTmaKUyz1wJ/07mHJi3BfJzvl31jywh6P
4P3nOMSsuXu/0IP69B54sP+KE1WxGo9H8H/hYVsOtMS/82IT2ygpPXPkoWHk
o/eCY1399o6ypGFfvkH2D7IxTfA=
       "]], LineBox[CompressedData["
1:eJxdV3k4lGsbx9eCPkllqZR8llLSIqXQq3AUaZEW0kI+0SYpfBUp0YYKHUeU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       "]]}}, {}}},
  AspectRatio->0.2,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {True, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{None, None}, {{{0., 
       FormBox["\"0 Mb\"", TraditionalForm]}, {0.12133481939366733`, 
       FormBox["\"30 Mb\"", TraditionalForm]}, {0.24266963878733466`, 
       FormBox["\"60 Mb\"", TraditionalForm]}, {0.364004458181002, 
       FormBox["\"90 Mb\"", TraditionalForm]}, {0.4853392775746693, 
       FormBox["\"120 Mb\"", TraditionalForm]}, {0.6066740969683367, 
       FormBox["\"150 Mb\"", TraditionalForm]}, {0.728008916362004, 
       FormBox["\"180 Mb\"", TraditionalForm]}, {0.8493437357556713, 
       FormBox["\"210 Mb\"", TraditionalForm]}, {0.9706785551493387, 
       FormBox["\"240 Mb\"", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {-0.01, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677571031073939*^9}]
}, Open  ]],

Cell[TextData[{
 "Diese neue Grafik ist in Abb.2.31 dargestellt. \n\nEine Anwendung auf \
beliebige Chromosomen ist nun sehr einfach. Wir f\[UDoubleDot]gen dazu die \
oben einzeln aufgef\[UDoubleDot]hrten Befehle in einem ",
 StyleBox["Module",
  FontWeight->"Bold"],
 "-Befehl zusammen. Dabei ist zu beachten, dass wir den Namen f\[UDoubleDot]r \
die urspr\[UDoubleDot]ngliche Datenliste, ",
 StyleBox["gwas1",
  FontWeight->"Bold"],
 ", festhalten. Die Aufl\[ODoubleDot]sung wird auf 400 Punkte entlang des \
Chromosoms festgelegt. "
}], "Text",
 CellChangeTimes->{
  3.674624132162808*^9, {3.674624188407894*^9, 3.6746241970609074`*^9}, {
   3.674624270467018*^9, 3.6746242751190248`*^9}, {3.674624370665169*^9, 
   3.6746243715281706`*^9}, {3.674624525607403*^9, 3.674624541586427*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeSNPdensityPlot", "[", "chr_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sx0", ",", " ", "sx1", ",", "sx2", ",", "sx3", ",", "sx4"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sx1", " ", "=", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"chr", "\[Equal]", "\"\<X\>\""}], ",", 
        RowBox[{"WolframAlpha", "[", 
         RowBox[{"\"\<human chromosome X ideogram\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Result\>\"", ",", "1"}], "}"}], ",", 
            "\"\<Content\>\""}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"WolframAlpha", "[", 
         RowBox[{
          RowBox[{"\"\<human chromosome \>\"", "<>", 
           RowBox[{"ToString", "[", "chr", "]"}], "<>", "\"\< ideogram\>\""}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<Result\>\"", ",", "1"}], "}"}], ",", 
            "\"\<Content\>\""}], "}"}]}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sx2", " ", "=", " ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"chr", "\[Equal]", "\"\<X\>\""}], ",", 
         RowBox[{"WolframAlpha", "[", 
          RowBox[{"\"\<human chromosome X\>\"", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}], 
              "}"}], ",", "\"\<NumberData\>\""}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"WolframAlpha", "[", 
          RowBox[{
           RowBox[{"\"\<human chromosome \>\"", "<>", 
            RowBox[{"ToString", "[", "chr", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<ChromosomeLength:GenomeSequenceData\>\"", ",", "1"}], "}"}]
              , ",", "\"\<NumberData\>\""}], "}"}]}], "]"}]}], "]"}], "*", 
       "1000000"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sx0", " ", "=", " ", 
      RowBox[{"sx2", "/", "400"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sx3", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", 
           RowBox[{"k1", "/", "sx2"}], "]"}], ",", 
          RowBox[{"Count", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Cases", "[", 
              RowBox[{"gwas1", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n1_", ",", "n2_", ",", "n3__"}], "}"}], " ", "/;", 
                " ", 
                RowBox[{"n2", "\[Equal]", 
                 RowBox[{"\"\<chr\>\"", "<>", 
                  RowBox[{"ToString", "[", "chr", "]"}]}]}]}]}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
            RowBox[{"nn1_Integer", " ", "/;", " ", 
             RowBox[{"k1", "\[LessEqual]", " ", "nn1", "\[LessEqual]", " ", 
              RowBox[{"k1", "+", "sx0"}]}]}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k1", ",", "0", ",", "sx2", ",", "sx0"}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"sx4", " ", "=", " ", 
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{"sx3", " ", "/.", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"n1_", ",", "n2_"}], "}"}], "\[Rule]", " ", 
          RowBox[{"{", 
           RowBox[{"n1", ",", 
            RowBox[{
             RowBox[{"0.2", " ", 
              RowBox[{"n2", "/", 
               RowBox[{"Max", "[", 
                RowBox[{"Flatten", "[", "sx3", "]"}], "]"}]}]}], "+", 
             "0.05"}]}], "}"}]}]}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"AspectRatio", "\[Rule]", "0.2"}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.01"}], ",", "0.25"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Frame", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}],
         ",", 
        RowBox[{"FrameTicks", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"None", ",", "None"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"sx1", "[", 
                RowBox[{"[", 
                 RowBox[{
                 "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", 
                  "2", ",", "2", ",", "1"}], "]"}], "]"}], " ", "/.", " ", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"n1_Real", ",", " ", 
                  RowBox[{"FormBox", "[", 
                   RowBox[{"n2_String", ",", "n3__"}], "]"}]}], "}"}], 
                "\[RuleDelayed]", " ", 
                RowBox[{"{", 
                 RowBox[{"n1", ",", 
                  RowBox[{"StringDrop", "[", 
                   RowBox[{
                    RowBox[{"StringDrop", "[", 
                    RowBox[{"n2", ",", "1"}], "]"}], ",", 
                    RowBox[{"-", "1"}]}], "]"}]}], "}"}]}]}], ")"}], ",", 
             "None"}], "}"}]}], "}"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"sx4", ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"sx1", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
          "]"}], "]"}], "]"}], ",", "sx4", ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"\"\<Chromosome \>\"", "<>", 
         RowBox[{"ToString", "[", "chr", "]"}]}]}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.614045397188788*^9, 3.614045445948135*^9}, {
   3.614045479620264*^9, 3.614045482756497*^9}, {3.614045533240099*^9, 
   3.614045625010065*^9}, {3.614046517930068*^9, 3.6140467934946327`*^9}, 
   3.614052867309596*^9, {3.6140529019849663`*^9, 3.614052911425762*^9}, {
   3.614052945836672*^9, 3.614052978638124*^9}, 3.614053079595778*^9, {
   3.614053184735325*^9, 3.6140532058212337`*^9}, 3.614217492506922*^9, 
   3.6142292972419357`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell["\<\
Abbildung 2.32 illustriert die Verwendung dieser Routine f\[UDoubleDot]r zwei \
weitere Chromosomen.\
\>", "Text",
 CellChangeTimes->{{3.6746245486834383`*^9, 3.674624561498457*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeSNPdensityPlot", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.614052853565493*^9, 3.614052875340455*^9}, {
   3.614052984565557*^9, 3.614052984755663*^9}, {3.61421729325782*^9, 
   3.614217293396563*^9}, 3.614217503805532*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdUj1Iw2AQDY6dO1fcqoOLc7hR18a1k6irFZwqONnBxSIIUhFRWvGHGltr
bVo7iK4VunWuq65xNvfd3YPmIPn48t699+7IwsZOsDXned5y8vBptetnJvXS
I+1nw9VpeZOeknc27Ol9jwyPcpWfQnRA32UGHhQ/pL77HtJ5jesIuPCPaalY
/YjzTfot8JeTVP8pcHbxM2fwE70a8EV3XqTyXCrvnholBq6QR/yu0b/iqk6z
8zZw/4zzCfMG+STPLfQCZ3hHsrUWfA2fat9s3iZ45mN4pH3mZ7rGk3la0F9z
Bm3wZb429PhdrD6n5u1Az40z6aTmf4H+PB+5LvplH13N8U7brl5pXYLrfnrI
E+p/Y/qB8iz3H8vFUep/6cPPtfkD6Ms+B+C7eJU36Ml+h/D7GnENdY9j+gcb
5V1r
       "]], LineBox[CompressedData["
1:eJxdmDuQG0UQhgXhkTo2kBlSSF0TQmqTuggoHiGG0JA6NimkkEDBYWOMjyow
53v7fA9Jp5Osk3TaXa20K+1DJBBTmn/4u+pXstU7Mz3d/U339Or1Dz69+dHL
jUbjw5cajdXz+Gj1+8M1/K/pPru+1vv29p/uzVv3tv659qO7sv5OfOfKE8ob
V+8WNzaeuOTOauQH51/f+st98/Xq933Qs8n5N/2CTfduvFrwwH13e7XBJtf/
e2010WTMexr03A96n7rf/b7rrryxUmjj3tzrW9zPm3PPZK8u3qJ9b/nfNsdX
Wq/eNXmlba23HfZ54N7w73do3xc+IDshTj85xG+H9r3qFe5Sxrxd6t/25u3S
HsR3j/o+9r89ifee+9JP/NV5d9f23Sv++TjEf5/7eXXr+1yPOB3QfvA4cO9B
ceBxwHiCxwHtAY9nXA+7n5En4mTj4HEoPA5pH3gcCo/nwuM59wcPk8HjiDJ4
HHE9eBwFv+4HHsccx7pjxhM8jmk/eJzQPvA44X4I2wnng8ep+8r7+Uvgccr9
wOPUvR84/Z9nP/v3j4M/TcmXJuMF/5rcH3415fzZevBrynlskS+4tbgezxbn
w+8W/UN8bD14txhfxKst+diW82wyzkOb+yGebcnXtsT3TM6LyYj3GeOP83NG
exD/MzlPNo5nh/uDR0fypSPnzcYRB5PBoyM8OsLjXOrdOf3BPudS/2wcPGw9
eJxLve7SXvDochw8utQHHl05313h0RUePeHRo3/g0ZN8tvngYTLU9eT+eEEZ
PEwGD5PBw2TwMBk8TAYPk8GjTxk8+sKjL/WvTz7gYfPBoy/1/YLxAY8L6gOP
C+YTeNg4eFyQD3iYPvAYuM/DvQ0eA+oDjwH1gceA9xt4DOT+G1A//BzyvgGP
ofAYyv04FB5D4TGU+38oPEbCYyT1auReeDsfhnkj2gseI/oDP0esD+BxSf3g
cSn5cUn7wONSeJgMHqYPPMaSH2PJj7HwGNM/8BgLjzF5gUfE+fAnknyJyB/+
RVLPIjl/kdS3SM5jJDxNRjwiqX8R71fEx/SDdyTxijkO/jHjhfjFch5i6T9j
yVeTEd9Y7rdY+qVY8jmW+MfS78TSXyXCI2H8wCOR/iiR/EnkvkwknxI5j4n0
A4nU70R4JHJeE6mHidT3Cf0Dj4nwmNA/xGUi9/GE+mDXRHiYfry3+eAxoT/g
MSEf8LBx8DAZ81Lp51K531Opx6nkRyr5kXJ/8Ejl/kwlP1LhkQoPmw8eqfQL
qfCYCg+TwcNk8JhK/Z9KfkylX5rK/TaV/nUqPKbubb/vw8BjKvV2ynxB3GbS
n8y4H3jYOHjMyAc8ZiEuG4HHTOrVTPJjRv/xNP3gMRMeM+l3Zqy32Nf2A49M
7qtM6n0m+ZEJj0zyI5P8yLgf3mfSz2byPWn6wCOT7+VM6lVOPuCRy/2RS73K
pV6ZDB655Ecu33+55Ecu90cuPHLhkUu9yiU/5nJ/zDkOHnOeH/g9J1/wmEt/
MZf+dS71ai71ai79+Vx4mIx9bT7itpB+cSH5sWC+gseC5wk8FtK/LOT7cUHe
4GHzoWch+WEyeNh68LD9EdcF4wkehdSrgucDPAqpVyaDh8ngUUi/VAiPQr4v
CuFRyH1e0H7YXQiPUupVKf8/lNI/llKvTAaPUu5z0wceNh92le417+ijwKMk
f/AoGW/wKMkHPEqpV5XkRyX5UQmPSvqrSnhUtBc8KuFRyf1h+sCjEh5VeP8o
+FVJvaq5H3iYDB611KtaeNSSHzXvL/Co5T6v5f/KmucXPGqeH/Co3Sde72+B
R83/KcHD1oPHUniYDB5L2g87ltJfLakP60wGj6X0u0vhsZTvpSX9AY+l9LtL
xhf7/E19/wEuZ+yz
       "]]}}, {}}, 
   {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.0015]}], 
    PolygonBox[{{{0.026944444444444444`, 0}, {0.005555555555555555, 0}, {
       0.005555555555555554, 0.}, {0.004590843457405942, 
       0.00008440137215439975}, {0.00365544364819073, 
       0.00033504099563384186`}, {0.002777777777777775, 
       0.0007443033123086754}, {0.001984513279519225, 
       0.0012997530937834557`}, {0.0012997530937834557`, 
       0.001984513279519226}, {0.0007443033123086746, 0.002777777777777777}, {
       0.00033504099563384186`, 0.003655443648190729}, {
       0.00008440137215439888, 0.004590843457405944}, {0., 
       0.005555555555555556}, {0., 0.005555555555555555}, {0., 
       0.016666666666666663`}, {0., 0.016666666666666663`}, {
       0.00008440137215439975, 0.017631378764816276`}, {0.0003350409956338427,
        0.018566778574031488`}, {0.0007443033123086737, 
       0.01944444444444444}, {0.0012997530937834557`, 
       0.020237708942702992`}, {0.0019845132795192257`, 
       0.020922469128438762`}, {0.002777777777777776, 
       0.021477918909913542`}, {0.003655443648190729, 
       0.021887181226588375`}, {0.004590843457405942, 
       0.022137820850067817`}, {0.005555555555555555, 0.02222222222222222}, {
       0.005555555555555555, 0.02222222222222222}, {0.026944444444444444`, 
       0.02222222222222222}, {0.026944444444444444`, 0}}, {{
       0.026944444444444444`, 0}, {0.026944444444444444`, 
       0.02222222222222222}, {0.03930555555555556, 0.02222222222222222}, {
       0.03930555555555556, 0}, {0.026944444444444444`, 0}}, {{
       0.03930555555555556, 0}, {0.03930555555555556, 0.02222222222222222}, {
       0.06625, 0.02222222222222222}, {0.06625, 0}, {
       0.03930555555555556, 0}}, {{0.06625, 0}, {0.06625, 
       0.02222222222222222}, {0.08284722222222222, 0.02222222222222222}, {
       0.08284722222222222, 0}, {0.06625, 0}}, {{0.08284722222222222, 0}, {
       0.08284722222222222, 0.02222222222222222}, {0.09111111111111111, 
       0.02222222222222222}, {0.09111111111111111, 0}, {
       0.08284722222222222, 0}}, {{0.09111111111111111, 0}, {
       0.09111111111111111, 0.02222222222222222}, {0.10868055555555556`, 
       0.02222222222222222}, {0.10868055555555556`, 0}, {
       0.09111111111111111, 0}}, {{0.10868055555555556`, 0}, {
       0.10868055555555556`, 0.02222222222222222}, {0.12423611111111112`, 
       0.02222222222222222}, {0.12423611111111112`, 0}, {
       0.10868055555555556`, 0}}, {{0.12423611111111112`, 0}, {
       0.12423611111111112`, 0.02222222222222222}, {0.1325, 
       0.02222222222222222}, {0.1325, 0}, {0.12423611111111112`, 0}}, {{
       0.1325, 0}, {0.1325, 0.02222222222222222}, {0.14076388888888888`, 
       0.02222222222222222}, {0.14076388888888888`, 0}, {0.1325, 0}}, {{
       0.14076388888888888`, 0}, {0.14076388888888888`, 
       0.02222222222222222}, {0.15944444444444444`, 0.02222222222222222}, {
       0.15944444444444444`, 0}, {0.14076388888888888`, 0}}, {{
       0.15944444444444444`, 0}, {0.15944444444444444`, 
       0.02222222222222222}, {0.16770833333333332`, 0.02222222222222222}, {
       0.16770833333333332`, 0}, {0.15944444444444444`, 0}}, {{
       0.16770833333333332`, 0}, {0.16770833333333332`, 
       0.02222222222222222}, {0.18118055555555557`, 0.02222222222222222}, {
       0.18118055555555557`, 0}, {0.16770833333333332`, 0}}, {{
       0.18118055555555557`, 0}, {0.18118055555555557`, 
       0.02222222222222222}, {0.20597222222222222`, 0.02222222222222222}, {
       0.20597222222222222`, 0}, {0.18118055555555557`, 0}}, {{
       0.20597222222222222`, 0}, {0.20597222222222222`, 
       0.02222222222222222}, {0.22361111111111112`, 0.02222222222222222}, {
       0.22361111111111112`, 0}, {0.20597222222222222`, 0}}, {{
       0.22361111111111112`, 0}, {0.22361111111111112`, 
       0.02222222222222222}, {0.22875, 0.02222222222222222}, {0.22875, 0}, {
       0.22361111111111112`, 0}}, {{0.22875, 0}, {0.22875, 
       0.02222222222222222}, {0.24638888888888888`, 0.02222222222222222}, {
       0.24638888888888888`, 0}, {0.22875, 0}}, {{0.24638888888888888`, 0}, {
       0.24638888888888888`, 0.02222222222222222}, {0.26090277777777776`, 
       0.02222222222222222}, {0.26090277777777776`, 0}, {
       0.24638888888888888`, 0}}, {{0.26090277777777776`, 0}, {
       0.26090277777777776`, 0.02222222222222222}, {0.27326388888888886`, 
       0.02222222222222222}, {0.27326388888888886`, 0}, {
       0.26090277777777776`, 0}}, {{0.27326388888888886`, 0}, {
       0.27326388888888886`, 0.02222222222222222}, {0.2856944444444444, 
       0.02222222222222222}, {0.2856944444444444, 0}, {
       0.27326388888888886`, 0}}, {{0.2856944444444444, 0}, {
       0.2856944444444444, 0.02222222222222222}, {0.295, 
       0.02222222222222222}, {0.295, 0}, {0.2856944444444444, 0}}, {{
       0.295, 0}, {0.295, 0.02222222222222222}, {0.3022916666666667, 
       0.02222222222222222}, {0.3022916666666667, 0}, {0.295, 0}}, {{
       0.3022916666666667, 0}, {0.3022916666666667, 0.02222222222222222}, {
       0.3375, 0.02222222222222222}, {0.3375, 0}, {0.3022916666666667, 0}}, {{
       0.3375, 0}, {0.3375, 0.02222222222222222}, {0.36854166666666666`, 
       0.02222222222222222}, {0.36854166666666666`, 0}, {0.3375, 0}}, {{
       0.36854166666666666`, 0}, {0.36854166666666666`, 
       0.02222222222222222}, {0.37395833333333334`, 0.02222222222222222}, {
       0.37395833333333334`, 0.02222222222222222}, {0.37588775752963255`, 
       0.022053419477913422`}, {0.377758557148063, 0.021552140230954534`}, {
       0.3795138888888889, 0.020733615597604872`}, {0.381100417885406, 
       0.019622716034655308`}, {0.38246993825687753`, 
       0.018253195663183768`}, {0.3835808378198271, 0.016666666666666663`}, {
       0.38439936245317674`, 0.014911334925840762`}, {0.38490064170013566`, 
       0.013040535307410336`}, {0.38506944444444446`, 0.01111111111111111}, {
       0.38506944444444446`, 0.01111111111111111}, {0.38506944444444446`, 
       0.01111111111111111}, {0.38506944444444446`, 0.01111111111111111}, {
       0.38490064170013566`, 0.009181686914811884}, {0.38439936245317674`, 
       0.007310887296381458}, {0.3835808378198271, 0.005555555555555556}, {
       0.38246993825687753`, 0.003969026559038452}, {0.381100417885406, 
       0.0025995061875669113`}, {0.3795138888888889, 
       0.0014886066246173491`}, {0.377758557148063, 0.0006700819912676854}, {
       0.37588775752963255`, 0.0001688027443087995}, {0.37395833333333334`, 
       0.}, {0.37395833333333334`, 0}, {0.36854166666666666`, 0}}, {{
       0.3975, 0}, {0.3961805555555556, 0}, {0.3961805555555556, 0.}, {
       0.3942511313592564, 0.0001688027443087995}, {0.3923803317408259, 
       0.0006700819912676837}, {0.39062500000000006`, 
       0.0014886066246173509`}, {0.38903847100348293`, 
       0.0025995061875669113`}, {0.3876689506320114, 0.003969026559038452}, {
       0.3865580510690618, 0.005555555555555554}, {0.3857395264357122, 
       0.007310887296381458}, {0.38523824718875327`, 0.009181686914811887}, {
       0.38506944444444446`, 0.011111111111111112`}, {0.38506944444444446`, 
       0.01111111111111111}, {0.38506944444444446`, 0.01111111111111111}, {
       0.38506944444444446`, 0.011111111111111112`}, {0.38523824718875327`, 
       0.013040535307410336`}, {0.3857395264357122, 0.014911334925840763`}, {
       0.3865580510690618, 0.016666666666666663`}, {0.3876689506320114, 
       0.01825319566318377}, {0.38903847100348293`, 0.019622716034655308`}, {
       0.39062500000000006`, 0.020733615597604872`}, {0.3923803317408259, 
       0.021552140230954538`}, {0.3942511313592564, 0.022053419477913422`}, {
       0.3961805555555556, 0.02222222222222222}, {0.3961805555555556, 
       0.02222222222222222}, {0.3975, 0.02222222222222222}, {0.3975, 0}}, {{
       0.3975, 0}, {0.3975, 0.02222222222222222}, {0.4181944444444444, 
       0.02222222222222222}, {0.4181944444444444, 0}, {0.3975, 0}}, {{
       0.4181944444444444, 0}, {0.4181944444444444, 0.02222222222222222}, {
       0.4347916666666667, 0.02222222222222222}, {0.4347916666666667, 0}, {
       0.4181944444444444, 0}}, {{0.4347916666666667, 0}, {0.4347916666666667,
        0.02222222222222222}, {0.4440972222222222, 0.02222222222222222}, {
       0.4440972222222222, 0}, {0.4347916666666667, 0}}, {{
       0.4440972222222222, 0}, {0.4440972222222222, 0.02222222222222222}, {
       0.4554861111111111, 0.02222222222222222}, {0.4554861111111111, 0}, {
       0.4440972222222222, 0}}, {{0.4554861111111111, 0}, {0.4554861111111111,
        0.02222222222222222}, {0.47305555555555556`, 0.02222222222222222}, {
       0.47305555555555556`, 0}, {0.4554861111111111, 0}}, {{
       0.47305555555555556`, 0}, {0.47305555555555556`, 
       0.02222222222222222}, {0.4886111111111111, 0.02222222222222222}, {
       0.4886111111111111, 0}, {0.47305555555555556`, 0}}, {{
       0.4886111111111111, 0}, {0.4886111111111111, 0.02222222222222222}, {
       0.5093055555555556, 0.02222222222222222}, {0.5093055555555556, 0}, {
       0.4886111111111111, 0}}, {{0.5093055555555556, 0}, {0.5093055555555556,
        0.02222222222222222}, {0.5279166666666667, 0.02222222222222222}, {
       0.5279166666666667, 0}, {0.5093055555555556, 0}}, {{
       0.5279166666666667, 0}, {0.5279166666666667, 0.02222222222222222}, {
       0.5434722222222222, 0.02222222222222222}, {0.5434722222222222, 0}, {
       0.5279166666666667, 0}}, {{0.5434722222222222, 0}, {0.5434722222222222,
        0.02222222222222222}, {0.5590277777777778, 0.02222222222222222}, {
       0.5590277777777778, 0}, {0.5434722222222222, 0}}, {{
       0.5590277777777778, 0}, {0.5590277777777778, 0.02222222222222222}, {
       0.5672916666666666, 0.02222222222222222}, {0.5672916666666666, 0}, {
       0.5590277777777778, 0}}, {{0.5672916666666666, 0}, {0.5672916666666666,
        0.02222222222222222}, {0.5859027777777778, 0.02222222222222222}, {
       0.5859027777777778, 0}, {0.5672916666666666, 0}}, {{
       0.5859027777777778, 0}, {0.5859027777777778, 0.02222222222222222}, {
       0.5900694444444444, 0.02222222222222222}, {0.5900694444444444, 0}, {
       0.5859027777777778, 0}}, {{0.5900694444444444, 0}, {0.5900694444444444,
        0.02222222222222222}, {0.6004166666666667, 0.02222222222222222}, {
       0.6004166666666667, 0}, {0.5900694444444444, 0}}, {{
       0.6004166666666667, 0}, {0.6004166666666667, 0.02222222222222222}, {
       0.6065972222222222, 0.02222222222222222}, {0.6065972222222222, 0}, {
       0.6004166666666667, 0}}, {{0.6065972222222222, 0}, {0.6065972222222222,
        0.02222222222222222}, {0.6107638888888889, 0.02222222222222222}, {
       0.6107638888888889, 0}, {0.6065972222222222, 0}}, {{
       0.6107638888888889, 0}, {0.6107638888888889, 0.02222222222222222}, {
       0.6304166666666666, 0.02222222222222222}, {0.6304166666666666, 0}, {
       0.6107638888888889, 0}}, {{0.6304166666666666, 0}, {0.6304166666666666,
        0.02222222222222222}, {0.6500694444444445, 0.02222222222222222}, {
       0.6500694444444445, 0}, {0.6304166666666666, 0}}, {{
       0.6500694444444445, 0}, {0.6500694444444445, 0.02222222222222222}, {
       0.665625, 0.02222222222222222}, {0.665625, 0}, {
       0.6500694444444445, 0}}, {{0.665625, 0}, {0.665625, 
       0.02222222222222222}, {0.6894444444444444, 0.02222222222222222}, {
       0.6894444444444444, 0}, {0.665625, 0}}, {{0.6894444444444444, 0}, {
       0.6894444444444444, 0.02222222222222222}, {0.7246527777777778, 
       0.02222222222222222}, {0.7246527777777778, 0}, {
       0.6894444444444444, 0}}, {{0.7246527777777778, 0}, {0.7246527777777778,
        0.02222222222222222}, {0.7360416666666667, 0.02222222222222222}, {
       0.7360416666666667, 0}, {0.7246527777777778, 0}}, {{
       0.7360416666666667, 0}, {0.7360416666666667, 0.02222222222222222}, {
       0.7453472222222223, 0.02222222222222222}, {0.7453472222222223, 0}, {
       0.7360416666666667, 0}}, {{0.7453472222222223, 0}, {0.7453472222222223,
        0.02222222222222222}, {0.7702083333333334, 0.02222222222222222}, {
       0.7702083333333334, 0}, {0.7453472222222223, 0}}, {{
       0.7702083333333334, 0}, {0.7702083333333334, 0.02222222222222222}, {
       0.7795138888888888, 0.02222222222222222}, {0.7795138888888888, 0}, {
       0.7702083333333334, 0}}, {{0.7795138888888888, 0}, {0.7795138888888888,
        0.02222222222222222}, {0.80125, 0.02222222222222222}, {0.80125, 0}, {
       0.7795138888888888, 0}}, {{0.80125, 0}, {0.80125, 
       0.02222222222222222}, {0.828125, 0.02222222222222222}, {0.828125, 0}, {
       0.80125, 0}}, {{0.828125, 0}, {0.828125, 0.02222222222222222}, {0.8375,
        0.02222222222222222}, {0.8375, 0}, {0.828125, 0}}, {{0.8375, 0}, {
       0.8375, 0.02222222222222222}, {0.8529861111111111, 
       0.02222222222222222}, {0.8529861111111111, 0}, {0.8375, 0}}, {{
       0.8529861111111111, 0}, {0.8529861111111111, 0.02222222222222222}, {
       0.8778472222222222, 0.02222222222222222}, {0.8778472222222222, 0}, {
       0.8529861111111111, 0}}, {{0.8778472222222222, 0}, {0.8778472222222222,
        0.02222222222222222}, {0.90375, 0.02222222222222222}, {0.90375, 0}, {
       0.8778472222222222, 0}}, {{0.90375, 0}, {0.90375, 
       0.02222222222222222}, {0.9192361111111111, 0.02222222222222222}, {
       0.9192361111111111, 0}, {0.90375, 0}}, {{0.9192361111111111, 0}, {
       0.9192361111111111, 0.02222222222222222}, {0.9234027777777778, 
       0.02222222222222222}, {0.9234027777777778, 0}, {
       0.9192361111111111, 0}}, {{0.9234027777777778, 0}, {0.9234027777777778,
        0.02222222222222222}, {0.9440972222222223, 0.02222222222222222}, {
       0.9440972222222223, 0}, {0.9234027777777778, 0}}, {{
       0.9440972222222223, 0}, {0.9440972222222223, 0.02222222222222222}, {
       0.9647916666666667, 0.02222222222222222}, {0.9647916666666667, 0}, {
       0.9440972222222223, 0}}, {{0.9647916666666667, 0}, {0.9647916666666667,
        0.02222222222222222}, {0.9720833333333333, 0.02222222222222222}, {
       0.9720833333333333, 0}, {0.9647916666666667, 0}}, {{
       0.9720833333333333, 0}, {0.9720833333333333, 0.02222222222222222}, {
       0.9944444444444445, 0.02222222222222222}, {0.9944444444444445, 
       0.02222222222222222}, {0.9954091565425941, 0.022137820850067817`}, {
       0.9963445563518093, 0.021887181226588375`}, {0.9972222222222222, 
       0.021477918909913546`}, {0.9980154867204808, 0.020922469128438762`}, {
       0.9987002469062166, 0.020237708942702992`}, {0.9992556966876913, 
       0.01944444444444444}, {0.9996649590043661, 0.018566778574031488`}, {
       0.9999155986278456, 0.017631378764816276`}, {1., 
       0.016666666666666663`}, {1., 0.016666666666666663`}, {1., 
       0.005555555555555555}, {1., 0.005555555555555555}, {0.9999155986278456,
        0.004590843457405942}, {0.9996649590043661, 0.003655443648190729}, {
       0.9992556966876913, 0.002777777777777778}, {0.9987002469062166, 
       0.001984513279519226}, {0.9980154867204808, 0.0012997530937834557`}, {
       0.9972222222222222, 0.0007443033123086746}, {0.9963445563518093, 
       0.0003350409956338427}, {0.9954091565425941, 0.00008440137215439975}, {
       0.9944444444444445, 0.}, {0.9944444444444445, 0}, {
       0.9720833333333333, 0}}},
     VertexColors->{{1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
       1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
       0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 
       1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
       1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 1.}, {0.25, 0.25,
        0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
       1., 1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0., 
       0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 
       1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0., 
       0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25}, {0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {
       1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 1., 1., 1., 
       1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
       0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1., 
       1., 1., 1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0., 0., 
       0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.75, 0.75, 0.75, 0.75, 0.75}, {1.,
        1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
       1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 
       0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {
       1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 
       1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1.}, {0., 0., 0., 0., 
       0.}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1.,
        1., 1.}, {0., 0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 
       0.5, 0.5}, {1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
        1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}}], 
    {RGBColor[1, 0, 0], EdgeForm[None], PolygonBox[{}]}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdUj1Iw2AQDY6dO1fcqoOLc7hR18a1k6irFZwqONnBxSIIUhFRWvGHGltr
bVo7iK4VunWuq65xNvfd3YPmIPn48t699+7IwsZOsDXned5y8vBptetnJvXS
I+1nw9VpeZOeknc27Ol9jwyPcpWfQnRA32UGHhQ/pL77HtJ5jesIuPCPaalY
/YjzTfot8JeTVP8pcHbxM2fwE70a8EV3XqTyXCrvnholBq6QR/yu0b/iqk6z
8zZw/4zzCfMG+STPLfQCZ3hHsrUWfA2fat9s3iZ45mN4pH3mZ7rGk3la0F9z
Bm3wZb429PhdrD6n5u1Az40z6aTmf4H+PB+5LvplH13N8U7brl5pXYLrfnrI
E+p/Y/qB8iz3H8vFUep/6cPPtfkD6Ms+B+C7eJU36Ml+h/D7GnENdY9j+gcb
5V1r
       "]], LineBox[CompressedData["
1:eJxdmDuQG0UQhgXhkTo2kBlSSF0TQmqTuggoHiGG0JA6NimkkEDBYWOMjyow
53v7fA9Jp5Osk3TaXa20K+1DJBBTmn/4u+pXstU7Mz3d/U339Or1Dz69+dHL
jUbjw5cajdXz+Gj1+8M1/K/pPru+1vv29p/uzVv3tv659qO7sv5OfOfKE8ob
V+8WNzaeuOTOauQH51/f+st98/Xq933Qs8n5N/2CTfduvFrwwH13e7XBJtf/
e2010WTMexr03A96n7rf/b7rrryxUmjj3tzrW9zPm3PPZK8u3qJ9b/nfNsdX
Wq/eNXmlba23HfZ54N7w73do3xc+IDshTj85xG+H9r3qFe5Sxrxd6t/25u3S
HsR3j/o+9r89ifee+9JP/NV5d9f23Sv++TjEf5/7eXXr+1yPOB3QfvA4cO9B
ceBxwHiCxwHtAY9nXA+7n5En4mTj4HEoPA5pH3gcCo/nwuM59wcPk8HjiDJ4
HHE9eBwFv+4HHsccx7pjxhM8jmk/eJzQPvA44X4I2wnng8ep+8r7+Uvgccr9
wOPUvR84/Z9nP/v3j4M/TcmXJuMF/5rcH3415fzZevBrynlskS+4tbgezxbn
w+8W/UN8bD14txhfxKst+diW82wyzkOb+yGebcnXtsT3TM6LyYj3GeOP83NG
exD/MzlPNo5nh/uDR0fypSPnzcYRB5PBoyM8OsLjXOrdOf3BPudS/2wcPGw9
eJxLve7SXvDochw8utQHHl05313h0RUePeHRo3/g0ZN8tvngYTLU9eT+eEEZ
PEwGD5PBw2TwMBk8TAYPk8GjTxk8+sKjL/WvTz7gYfPBoy/1/YLxAY8L6gOP
C+YTeNg4eFyQD3iYPvAYuM/DvQ0eA+oDjwH1gceA9xt4DOT+G1A//BzyvgGP
ofAYyv04FB5D4TGU+38oPEbCYyT1auReeDsfhnkj2gseI/oDP0esD+BxSf3g
cSn5cUn7wONSeJgMHqYPPMaSH2PJj7HwGNM/8BgLjzF5gUfE+fAnknyJyB/+
RVLPIjl/kdS3SM5jJDxNRjwiqX8R71fEx/SDdyTxijkO/jHjhfjFch5i6T9j
yVeTEd9Y7rdY+qVY8jmW+MfS78TSXyXCI2H8wCOR/iiR/EnkvkwknxI5j4n0
A4nU70R4JHJeE6mHidT3Cf0Dj4nwmNA/xGUi9/GE+mDXRHiYfry3+eAxoT/g
MSEf8LBx8DAZ81Lp51K531Opx6nkRyr5kXJ/8Ejl/kwlP1LhkQoPmw8eqfQL
qfCYCg+TwcNk8JhK/Z9KfkylX5rK/TaV/nUqPKbubb/vw8BjKvV2ynxB3GbS
n8y4H3jYOHjMyAc8ZiEuG4HHTOrVTPJjRv/xNP3gMRMeM+l3Zqy32Nf2A49M
7qtM6n0m+ZEJj0zyI5P8yLgf3mfSz2byPWn6wCOT7+VM6lVOPuCRy/2RS73K
pV6ZDB655Ecu33+55Ecu90cuPHLhkUu9yiU/5nJ/zDkOHnOeH/g9J1/wmEt/
MZf+dS71ai71ai79+Vx4mIx9bT7itpB+cSH5sWC+gseC5wk8FtK/LOT7cUHe
4GHzoWch+WEyeNh68LD9EdcF4wkehdSrgucDPAqpVyaDh8ngUUi/VAiPQr4v
CuFRyH1e0H7YXQiPUupVKf8/lNI/llKvTAaPUu5z0wceNh92le417+ijwKMk
f/AoGW/wKMkHPEqpV5XkRyX5UQmPSvqrSnhUtBc8KuFRyf1h+sCjEh5VeP8o
+FVJvaq5H3iYDB611KtaeNSSHzXvL/Co5T6v5f/KmucXPGqeH/Co3Sde72+B
R83/KcHD1oPHUniYDB5L2g87ltJfLakP60wGj6X0u0vhsZTvpSX9AY+l9LtL
xhf7/E19/wEuZ+yz
       "]]}}, {}}},
  AspectRatio->0.2,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {True, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{None, None}, {{{0., 
       FormBox["\"0 Mb\"", TraditionalForm]}, {0.12348161399310771`, 
       FormBox["\"30 Mb\"", TraditionalForm]}, {0.24696322798621542`, 
       FormBox["\"60 Mb\"", TraditionalForm]}, {0.3704448419793232, 
       FormBox["\"90 Mb\"", TraditionalForm]}, {0.49392645597243084`, 
       FormBox["\"120 Mb\"", TraditionalForm]}, {0.6174080699655387, 
       FormBox["\"150 Mb\"", TraditionalForm]}, {0.7408896839586464, 
       FormBox["\"180 Mb\"", TraditionalForm]}, {0.864371297951754, 
       FormBox["\"210 Mb\"", TraditionalForm]}, {0.9878529119448617, 
       FormBox["\"240 Mb\"", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Chromosome 2\"", TraditionalForm],
  PlotRange->{{0, 1}, {-0.01, 0.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775710618245926`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeSNPdensityPlot", "[", "21", "]"}]], "Input",
 CellChangeTimes->{{3.614052853565493*^9, 3.614052875340455*^9}, {
  3.614052984565557*^9, 3.614052984755663*^9}, {3.61421729325782*^9, 
  3.614217293396563*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxd2DtsW2UYxvHAWNayFrGVGVbICGs6d0JQRorEVCQmOrAAlZBQEUKgFHER
VEALTaBALr0kzc1pnDghduJzfDvO8YUlzOT4cd5H/L1YT75z+97f93628+yr
b154/cmJiYlrT0xMFO+nr0+vF69vJ985e/Pl5Mprk//Pb0eePXc1n5p5F+Pv
Rdb7+zj+g8i9qZmTv1zD+R9HPlOZvvzimU9wveuRn7v44cLx+c9w/c8j3zg5
uzL9Be73ZeTnR69p3P9G5MXj8yd3+ArP83XkC8Xlpr7B8/k9vVJc8Ds87/eR
3yoe7/IPeP6bkaXxI+bj/EpS3OAnzM/5o4ViAj9jvrcij6ZTuYX53478TPE4
535BPZzfuFS8fkV97kQurnb25h3Uaybyv8XljmdQt9nIL40u+Bvq6Tx6vKu/
o753I6+tFq+7qPcfkZ8ePeCfqL/z6HIX/4LHHOYzB585zG8OXvOY7zz85jH/
BXg6jy6XLMB3EfVxlvci6nUP/vdQP2eth/uop7PWx33U9wHWywPU21nr5yHq
76z19BAeS/BYgscSPJbgsQyPZXgsw+MRPJy1Ph/BYwUeK/BYgccqPFbhsQqP
NXisweM0z4491uGxDg/np0YPuAGPDXhswKOE+ZTgU8L8SvAqYb4l+JUw/014
bqIem/DdRH024e2sej2G/2PUz1nrwVnbnbP61VnrfQvrZQv1dtb62UL9nbWe
tuBRhkcZHmV4lOFRhkcZHmV4bMNje/KF8eeOPLbh4XF5bMNjGx478NiJ8+Xh
LA8fr/W9A4+dyUvjfUkelThfHs7yqMCjAg8fr8tV4LEb4/JwlscuPDwuj114
7MJjFx578HCWxx48nOWxB489ePwND2d5OMvjNM+OPTyu/dNZHvvoD2d57MNj
Hx7O8tiHRxUeVfRHFR7O8qjCowqPKjxq8KjBowaP2vj5FscetXheedTgcQCP
A3gcwMNZHgfwOIj76fPgEB6H6I9DeBzC4xAeh/CoYz51+NQxvzq86phvHX51
7A91eDpr/67D11n7h68nb49r/SYxLv8E+0uC9eCseiZYHwnqm2C9JKi3s9ZP
gvonWE8JPFJ4OMsjjfPlkWI/S+HhcXmkWI8pPFJ4pPBI4ZHCI4VHA/14mmfH
Hg14NODRgEcDHo34PNHfG/BowKMBD2d5NODRhEcT/eFxeTjLowkPZ3k00R9N
eDTh4ePl4SyPZtRXHk14tODRgkcrfnfJo4X9poXvFy14OOu9BY8WPFrwaKE/
nPVcbXi04dGGRxsebXx/aaM/fLw82vBoR720fzvLow0Pny+PNjw68HCWh7M8
OnE/eXTg0YGHx/V3ny+PTnjLowMPZ3k467wMHhk8MnhkcT95ZPE88sjgkcEj
g0cGjwz9kcEjw37lLI8uPLr4/HCWh4+Xh7M8uvDowsPj8nCWRzfqJY8u+qML
jyN4OMvjCB5H+PzwuDyOor7yOMJ+5SwPny8PZ3k46/uOszyc5ZHj8zyHR47+
yLFf5eiPPOopjxy/o328PHJ45OiPHP2RY7/qRZZHDx4el4fH5dGDRw/90UN/
9MJLHj14eFwePXj00B8+Xh59ePSjnvLow6OP/ujDow+PPvrD4/Low8PHy6M/
uT7+v408+uiPAfpjgP1qgP44HV8cewzi+4Y8fLw8BlEveXhcHgN4DNAfA3gM
4OFx/T4YxvPIY4j+GMJjCA9neTjLw1nvzvIYwmMIjyH6Y4j++CfG/wMtnnO/

       "]]}}, {}}, 
   {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.0015]}], 
    PolygonBox[{{{0.0971875, 0}, {0.005555555555555555, 0}, {
       0.005555555555555554, 0.}, {0.004590843457405942, 
       0.00008440137215439975}, {0.00365544364819073, 
       0.00033504099563384186`}, {0.002777777777777775, 
       0.0007443033123086754}, {0.001984513279519225, 
       0.0012997530937834557`}, {0.0012997530937834557`, 
       0.001984513279519226}, {0.0007443033123086746, 0.002777777777777777}, {
       0.00033504099563384186`, 0.003655443648190729}, {
       0.00008440137215439888, 0.004590843457405944}, {0., 
       0.005555555555555556}, {0., 0.005555555555555555}, {0., 
       0.016666666666666663`}, {0., 0.016666666666666663`}, {
       0.00008440137215439975, 0.017631378764816276`}, {0.0003350409956338427,
        0.018566778574031488`}, {0.0007443033123086737, 
       0.01944444444444444}, {0.0012997530937834557`, 
       0.020237708942702992`}, {0.0019845132795192257`, 
       0.020922469128438762`}, {0.002777777777777776, 
       0.021477918909913542`}, {0.003655443648190729, 
       0.021887181226588375`}, {0.004590843457405942, 
       0.022137820850067817`}, {0.005555555555555555, 0.02222222222222222}, {
       0.005555555555555555, 0.02222222222222222}, {0.0971875, 
       0.02222222222222222}, {0.0971875, 0}}, {{0.0971875, 0}, {0.0971875, 
       0.02222222222222222}, {0.2134375, 0.02222222222222222}, {
       0.2134375, 0}, {0.0971875, 0}}, {{0.2134375, 0}, {0.2134375, 
       0.02222222222222222}, {0.33, 0.02222222222222222}, {0.33, 0}, {
       0.2134375, 0}}, {{0.33, 0}, {0.33, 0.02222222222222222}, {
       0.3870138888888889, 0.02222222222222222}, {0.3870138888888889, 
       0.02222222222222222}, {0.3889433130851881, 0.022053419477913422`}, {
       0.39081411270361854`, 0.021552140230954534`}, {0.3925694444444444, 
       0.020733615597604872`}, {0.39415597344096154`, 
       0.019622716034655308`}, {0.39552549381243307`, 
       0.018253195663183768`}, {0.39663639337538265`, 
       0.016666666666666663`}, {0.3974549180087323, 0.014911334925840762`}, {
       0.3979561972556912, 0.013040535307410336`}, {0.398125, 
       0.01111111111111111}, {0.398125, 0.01111111111111111}, {0.398125, 
       0.01111111111111111}, {0.398125, 0.01111111111111111}, {
       0.3979561972556912, 0.009181686914811884}, {0.3974549180087323, 
       0.007310887296381458}, {0.39663639337538265`, 0.005555555555555556}, {
       0.39552549381243307`, 0.003969026559038452}, {0.39415597344096154`, 
       0.0025995061875669113`}, {0.3925694444444444, 
       0.0014886066246173491`}, {0.39081411270361854`, 
       0.0006700819912676854}, {0.3889433130851881, 0.0001688027443087995}, {
       0.3870138888888889, 0.}, {0.3870138888888889, 0}, {0.33, 0}}, {{
       0.4271875, 0}, {0.40923611111111113`, 0}, {0.40923611111111113`, 0.}, {
       0.4073066869148119, 0.0001688027443087995}, {0.40543588729638147`, 
       0.0006700819912676837}, {0.4036805555555556, 0.0014886066246173509`}, {
       0.4020940265590385, 0.0025995061875669113`}, {0.40072450618756694`, 
       0.003969026559038452}, {0.39961360662461737`, 0.005555555555555554}, {
       0.39879508199126773`, 0.007310887296381458}, {0.3982938027443088, 
       0.009181686914811887}, {0.398125, 0.011111111111111112`}, {0.398125, 
       0.01111111111111111}, {0.398125, 0.01111111111111111}, {0.398125, 
       0.011111111111111112`}, {0.3982938027443088, 0.013040535307410336`}, {
       0.39879508199126773`, 0.014911334925840763`}, {0.39961360662461737`, 
       0.016666666666666663`}, {0.40072450618756694`, 0.01825319566318377}, {
       0.4020940265590385, 0.019622716034655308`}, {0.4036805555555556, 
       0.020733615597604872`}, {0.40543588729638147`, 
       0.021552140230954538`}, {0.4073066869148119, 0.022053419477913422`}, {
       0.40923611111111113`, 0.02222222222222222}, {0.40923611111111113`, 
       0.02222222222222222}, {0.4271875, 0.02222222222222222}, {
       0.4271875, 0}}, {{0.4271875, 0}, {0.4271875, 0.02222222222222222}, {
       0.495, 0.02222222222222222}, {0.495, 0}, {0.4271875, 0}}, {{
       0.495, 0}, {0.495, 0.02222222222222222}, {0.6309375, 
       0.02222222222222222}, {0.6309375, 0}, {0.495, 0}}, {{0.6309375, 0}, {
       0.6309375, 0.02222222222222222}, {0.67, 0.02222222222222222}, {
       0.67, 0}, {0.6309375, 0}}, {{0.67, 0}, {0.67, 0.02222222222222222}, {
       0.728125, 0.02222222222222222}, {0.728125, 0}, {0.67, 0}}, {{
       0.728125, 0}, {0.728125, 0.02222222222222222}, {0.7765625, 
       0.02222222222222222}, {0.7765625, 0}, {0.728125, 0}}, {{
       0.7765625, 0}, {0.7765625, 0.02222222222222222}, {0.815625, 
       0.02222222222222222}, {0.815625, 0}, {0.7765625, 0}}, {{0.815625, 0}, {
       0.815625, 0.02222222222222222}, {0.8446875, 0.02222222222222222}, {
       0.8446875, 0}, {0.815625, 0}}, {{0.8446875, 0}, {0.8446875, 
       0.02222222222222222}, {0.8931250000000001, 0.02222222222222222}, {
       0.8931250000000001, 0}, {0.8446875, 0}}, {{0.8931250000000001, 0}, {
       0.8931250000000001, 0.02222222222222222}, {0.9944444444444445, 
       0.02222222222222222}, {0.9944444444444445, 0.02222222222222222}, {
       0.9954091565425941, 0.022137820850067817`}, {0.9963445563518093, 
       0.021887181226588375`}, {0.9972222222222222, 0.021477918909913546`}, {
       0.9980154867204808, 0.020922469128438762`}, {0.9987002469062166, 
       0.020237708942702992`}, {0.9992556966876913, 0.01944444444444444}, {
       0.9996649590043661, 0.018566778574031488`}, {0.9999155986278456, 
       0.017631378764816276`}, {1., 0.016666666666666663`}, {1., 
       0.016666666666666663`}, {1., 0.005555555555555555}, {1., 
       0.005555555555555555}, {0.9999155986278456, 0.004590843457405942}, {
       0.9996649590043661, 0.003655443648190729}, {0.9992556966876913, 
       0.002777777777777778}, {0.9987002469062166, 0.001984513279519226}, {
       0.9980154867204808, 0.0012997530937834557`}, {0.9972222222222222, 
       0.0007443033123086746}, {0.9963445563518093, 0.0003350409956338427}, {
       0.9954091565425941, 0.00008440137215439975}, {0.9944444444444445, 
       0.}, {0.9944444444444445, 0}, {0.8931250000000001, 0}}},
     VertexColors->{{0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 
       0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 
       0.5, 0.5}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25, 0.25}, {0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 
       0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25,
        0.25, 0.25, 0.25, 0.25, 0.25, 0.25, 0.25}, {1., 1., 1., 1., 1.}, {0., 
       0., 0., 0., 0.}, {1., 1., 1., 1., 1.}, {0.25, 0.25, 0.25, 0.25, 
       0.25}, {1., 1., 1., 1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 
       1., 1.}, {0.5, 0.5, 0.5, 0.5, 0.5}, {1., 1., 1., 1., 1., 1., 1., 1., 
       1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 1.,
        1.}}], 
    {RGBColor[1, 0, 0], EdgeForm[None], PolygonBox[{}]}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxd2DtsW2UYxvHAWNayFrGVGVbICGs6d0JQRorEVCQmOrAAlZBQEUKgFHER
VEALTaBALr0kzc1pnDghduJzfDvO8YUlzOT4cd5H/L1YT75z+97f93628+yr
b154/cmJiYlrT0xMFO+nr0+vF69vJ985e/Pl5Mprk//Pb0eePXc1n5p5F+Pv
Rdb7+zj+g8i9qZmTv1zD+R9HPlOZvvzimU9wveuRn7v44cLx+c9w/c8j3zg5
uzL9Be73ZeTnR69p3P9G5MXj8yd3+ArP83XkC8Xlpr7B8/k9vVJc8Ds87/eR
3yoe7/IPeP6bkaXxI+bj/EpS3OAnzM/5o4ViAj9jvrcij6ZTuYX53478TPE4
535BPZzfuFS8fkV97kQurnb25h3Uaybyv8XljmdQt9nIL40u+Bvq6Tx6vKu/
o753I6+tFq+7qPcfkZ8ePeCfqL/z6HIX/4LHHOYzB585zG8OXvOY7zz85jH/
BXg6jy6XLMB3EfVxlvci6nUP/vdQP2eth/uop7PWx33U9wHWywPU21nr5yHq
76z19BAeS/BYgscSPJbgsQyPZXgsw+MRPJy1Ph/BYwUeK/BYgccqPFbhsQqP
NXisweM0z4491uGxDg/np0YPuAGPDXhswKOE+ZTgU8L8SvAqYb4l+JUw/014
bqIem/DdRH024e2sej2G/2PUz1nrwVnbnbP61VnrfQvrZQv1dtb62UL9nbWe
tuBRhkcZHmV4lOFRhkcZHmV4bMNje/KF8eeOPLbh4XF5bMNjGx478NiJ8+Xh
LA8fr/W9A4+dyUvjfUkelThfHs7yqMCjAg8fr8tV4LEb4/JwlscuPDwuj114
7MJjFx578HCWxx48nOWxB489ePwND2d5OMvjNM+OPTyu/dNZHvvoD2d57MNj
Hx7O8tiHRxUeVfRHFR7O8qjCowqPKjxq8KjBowaP2vj5FscetXheedTgcQCP
A3gcwMNZHgfwOIj76fPgEB6H6I9DeBzC4xAeh/CoYz51+NQxvzq86phvHX51
7A91eDpr/67D11n7h68nb49r/SYxLv8E+0uC9eCseiZYHwnqm2C9JKi3s9ZP
gvonWE8JPFJ4OMsjjfPlkWI/S+HhcXmkWI8pPFJ4pPBI4ZHCI4VHA/14mmfH
Hg14NODRgEcDHo34PNHfG/BowKMBD2d5NODRhEcT/eFxeTjLowkPZ3k00R9N
eDTh4ePl4SyPZtRXHk14tODRgkcrfnfJo4X9poXvFy14OOu9BY8WPFrwaKE/
nPVcbXi04dGGRxsebXx/aaM/fLw82vBoR720fzvLow0Pny+PNjw68HCWh7M8
OnE/eXTg0YGHx/V3ny+PTnjLowMPZ3k467wMHhk8MnhkcT95ZPE88sjgkcEj
g0cGjwz9kcEjw37lLI8uPLr4/HCWh4+Xh7M8uvDowsPj8nCWRzfqJY8u+qML
jyN4OMvjCB5H+PzwuDyOor7yOMJ+5SwPny8PZ3k46/uOszyc5ZHj8zyHR47+
yLFf5eiPPOopjxy/o328PHJ45OiPHP2RY7/qRZZHDx4el4fH5dGDRw/90UN/
9MJLHj14eFwePXj00B8+Xh59ePSjnvLow6OP/ujDow+PPvrD4/Low8PHy6M/
uT7+v408+uiPAfpjgP1qgP44HV8cewzi+4Y8fLw8BlEveXhcHgN4DNAfA3gM
4OFx/T4YxvPIY4j+GMJjCA9neTjLw1nvzvIYwmMIjyH6Y4j++CfG/wMtnnO/

       "]]}}, {}}},
  AspectRatio->0.2,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {True, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{None, None}, {{{0., 
       FormBox["\"0 Mb\"", TraditionalForm]}, {0.6390549076615718, 
       FormBox["\"30 Mb\"", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Chromosome 21\"", TraditionalForm],
  PlotRange->{{0, 1}, {-0.01, 0.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775710892182407`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{612, Automatic}, {Automatic, 68}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 320, 9, 94, "Subtitle"],
Cell[1776, 71, 586, 18, 106, "Text"],
Cell[2365, 91, 283, 7, 47, "Input"],
Cell[2651, 100, 299, 6, 31, "Input"],
Cell[2953, 108, 529, 11, 125, "Text"],
Cell[CellGroupData[{
Cell[3507, 123, 135, 2, 31, "Input"],
Cell[3645, 127, 122, 3, 31, "Output"]
}, Open  ]],
Cell[3782, 133, 167, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[3974, 140, 147, 3, 31, "Input"],
Cell[4124, 145, 678, 11, 112, "Output"]
}, Open  ]],
Cell[4817, 159, 690, 12, 163, "Text"],
Cell[5510, 173, 522, 14, 52, "Input"],
Cell[6035, 189, 226, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[6286, 199, 555, 15, 52, "Input"],
Cell[6844, 216, 14052, 402, 229, "Output"]
}, Open  ]],
Cell[20911, 621, 308, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[21244, 632, 250, 6, 31, "Input"],
Cell[21497, 640, 2752, 74, 312, "Output"]
}, Open  ]],
Cell[24264, 717, 512, 11, 125, "Text"],
Cell[CellGroupData[{
Cell[24801, 732, 156, 2, 31, "Input"],
Cell[24960, 736, 33269, 548, 276, "Output"]
}, Open  ]],
Cell[58244, 1287, 226, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[58495, 1295, 285, 7, 72, "Input"],
Cell[58783, 1304, 424, 9, 49, "Output"]
}, Open  ]],
Cell[59222, 1316, 400, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[59647, 1328, 1311, 35, 252, "Input"],
Cell[60961, 1365, 1838, 47, 253, "Output"]
}, Open  ]],
Cell[62814, 1415, 457, 9, 106, "Text"],
Cell[63274, 1426, 1272, 36, 132, "Input"],
Cell[CellGroupData[{
Cell[64571, 1466, 1695, 43, 192, "Input"],
Cell[66269, 1511, 2857, 65, 152, "Output"]
}, Open  ]],
Cell[69141, 1579, 390, 8, 106, "Text"],
Cell[CellGroupData[{
Cell[69556, 1591, 363, 9, 72, "Input"],
Cell[69922, 1602, 22391, 354, 79, "Output"]
}, Open  ]],
Cell[92328, 1959, 507, 11, 125, "Text"],
Cell[92838, 1972, 555, 14, 92, "Input"],
Cell[93396, 1988, 177, 4, 31, "Input"],
Cell[93576, 1994, 895, 21, 182, "Text"],
Cell[94474, 2017, 1417, 32, 152, "Input"],
Cell[CellGroupData[{
Cell[95916, 2053, 2641, 66, 292, "Input"],
Cell[98560, 2121, 6927, 124, 97, "Output"]
}, Open  ]],
Cell[105502, 2248, 252, 6, 106, "Text"],
Cell[CellGroupData[{
Cell[105779, 2258, 528, 11, 52, "Input"],
Cell[106310, 2271, 30825, 479, 129, "Output"]
}, Open  ]],
Cell[137150, 2753, 790, 16, 163, "Text"],
Cell[137943, 2771, 6610, 163, 908, "Input"],
Cell[144556, 2936, 192, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[144773, 2944, 322, 6, 47, "Input"],
Cell[145098, 2952, 24418, 375, 142, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169553, 3332, 299, 6, 47, "Input"],
Cell[169855, 3340, 12343, 201, 177, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

